# -*- mode: python; coding: utf-8 -*-
# This work is dedicated to the public domain.

"""unicode_to_latex - what it says

Provides ``unicode_to_latex(u)``, ``unicode_to_latex_bytes(u)``, and
``unicode_to_latex_string(u)``.

``unicode_to_latex_bytes`` returns ASCII bytes that can be fed to LaTeX to
reproduce the Unicode string 'u' as closely as possible.

``unicode_to_latex_string`` returns a Unicode string rather than bytes.

``unicode_to_latex`` returns the ``str`` type: bytes on Python 2, Unicode on
Python 3.

"""

from __future__ import absolute_import, division, print_function

__all__ = "unicode_to_latex unicode_to_latex_bytes unicode_to_latex_string".split()

# Based on https://gist.github.com/798549 (owned by github user piquadrat),
# but modified to make a table usable with unicode.translate(). I had to
# comment out a few things and also tweak various of the conversions to make
# the LaTeX more natural. There were also some surprising missing conversions
# (e.g. u2010 -> -).

# The original table comes from http://www.w3.org/Math/characters/unicode.xml,
# converted via this XSL script: https://gist.github.com/798546 . Based on my
# experience so far, the source table is far from perfect.

unicode_to_latex_table_base = {
    "\u0023": rb"\#",
    "\u0024": rb"\textdollar{}",
    "\u0025": rb"\%",
    "\u0026": rb"\&",
    "\u0027": rb"'",
    "\u002A": rb"\ast{}",
    "\u005C": rb"\textbackslash{}",
    "\u005E": rb"\^{}",
    "\u005F": rb"\_",
    "\u0060": rb"\textasciigrave{}",
    "\u007B": rb"\lbrace{}",
    "\u007C": rb"\vert{}",
    "\u007D": rb"\rbrace{}",
    "\u007E": rb"\textasciitilde{}",
    "\u00A0": rb"~",
    "\u00A1": rb"\textexclamdown{}",
    "\u00A2": rb"\textcent{}",
    "\u00A3": rb"\textsterling{}",
    "\u00A4": rb"\textcurrency{}",
    "\u00A5": rb"\textyen{}",
    "\u00A6": rb"\textbrokenbar{}",
    "\u00A7": rb"\textsection{}",
    "\u00A8": rb"\textasciidieresis{}",
    "\u00A9": rb"\textcopyright{}",
    "\u00AA": rb"\textordfeminine{}",
    "\u00AB": rb"\guillemotleft{}",
    "\u00AC": rb"\lnot{}",
    "\u00AD": rb"\-",
    "\u00AE": rb"\textregistered{}",
    "\u00AF": rb"\textasciimacron{}",
    "\u00B0": rb"\textdegree{}",
    "\u00B1": rb"\pm{}",
    "\u00B2": rb"\ensuremath{^2}",
    "\u00B3": rb"\ensuremath{^3}",
    "\u00B4": rb"\textasciiacute{}",
    "\u00B5": rb"\mathrm{\mu}",
    "\u00B6": rb"\textparagraph{}",
    "\u00B7": rb"\cdot{}",
    "\u00B8": rb"\c{}",
    "\u00B9": rb"\ensuremath{^1}",
    "\u00BA": rb"\textordmasculine{}",
    "\u00BB": rb"\guillemotright{}",
    "\u00BC": rb"\textonequarter{}",
    "\u00BD": rb"\textonehalf{}",
    "\u00BE": rb"\textthreequarters{}",
    "\u00BF": rb"\textquestiondown{}",
    "\u00C0": rb"\`{A}",
    "\u00C1": rb"\'{A}",
    "\u00C2": rb"\^{A}",
    "\u00C3": rb"\~{A}",
    "\u00C4": rb"\"{A}",  # note single-quoted string
    "\u00C5": rb"\AA{}",
    "\u00C6": rb"\AE{}",
    "\u00C7": rb"\c{C}",
    "\u00C8": rb"\`{E}",
    "\u00C9": rb"\'{E}",
    "\u00CA": rb"\^{E}",
    "\u00CB": rb"\"{E}",  # note single-quoted string
    "\u00CC": rb"\`{I}",
    "\u00CD": rb"\'{I}",
    "\u00CE": rb"\^{I}",
    "\u00CF": rb"\"{I}",  # note single-quoted string
    "\u00D0": rb"\DH{}",
    "\u00D1": rb"\~{N}",
    "\u00D2": rb"\`{O}",
    "\u00D3": rb"\'{O}",
    "\u00D4": rb"\^{O}",
    "\u00D5": rb"\~{O}",
    "\u00D6": rb"\"{O}",  # note single-quoted string
    "\u00D7": rb"\texttimes{}",
    "\u00D8": rb"\O{}",
    "\u00D9": rb"\`{U}",
    "\u00DA": rb"\'{U}",
    "\u00DB": rb"\^{U}",
    "\u00DC": rb"\"{U}",  # note single-quoted string
    "\u00DD": rb"\'{Y}",
    "\u00DE": rb"\TH{}",
    "\u00DF": rb"\ss{}",
    "\u00E0": rb"\`{a}",
    "\u00E1": rb"\'{a}",
    "\u00E2": rb"\^{a}",
    "\u00E3": rb"\~{a}",
    "\u00E4": rb"\"{a}",  # note single-quoted string
    "\u00E5": rb"\aa{}",
    "\u00E6": rb"\ae{}",
    "\u00E7": rb"\c{c}",
    "\u00E8": rb"\`{e}",
    "\u00E9": rb"\'{e}",
    "\u00EA": rb"\^{e}",
    "\u00EB": rb"\"{e}",  # note single-quoted string
    "\u00EC": rb"\`{\i}",
    "\u00ED": rb"\'{\i}",
    "\u00EE": rb"\^{\i}",
    "\u00EF": rb"\"{\i}",  # note single-quoted string
    "\u00F0": rb"\dh{}",
    "\u00F1": rb"\~{n}",
    "\u00F2": rb"\`{o}",
    "\u00F3": rb"\'{o}",
    "\u00F4": rb"\^{o}",
    "\u00F5": rb"\~{o}",
    "\u00F6": rb"\"{o}",  # note single-quoted string
    "\u00F7": rb"\div{}",
    "\u00F8": rb"\o{}",
    "\u00F9": rb"\`{u}",
    "\u00FA": rb"\'{u}",
    "\u00FB": rb"\^{u}",
    "\u00FC": rb"\"{u}",  # note single-quoted string
    "\u00FD": rb"\'{y}",
    "\u00FE": rb"\th{}",
    "\u00FF": rb"\"{y}",  # note single-quoted string
    "\u0100": rb"\={A}",
    "\u0101": rb"\={a}",
    "\u0102": rb"\u{A}",
    "\u0103": rb"\u{a}",
    "\u0104": rb"\k{A}",
    "\u0105": rb"\k{a}",
    "\u0106": rb"\'{C}",
    "\u0107": rb"\'{c}",
    "\u0108": rb"\^{C}",
    "\u0109": rb"\^{c}",
    "\u010A": rb"\.{C}",
    "\u010B": rb"\.{c}",
    "\u010C": rb"\v{C}",
    "\u010D": rb"\v{c}",
    "\u010E": rb"\v{D}",
    "\u010F": rb"\v{d}",
    "\u0110": rb"\DJ{}",
    "\u0111": rb"\dj{}",
    "\u0112": rb"\={E}",
    "\u0113": rb"\={e}",
    "\u0114": rb"\u{E}",
    "\u0115": rb"\u{e}",
    "\u0116": rb"\.{E}",
    "\u0117": rb"\.{e}",
    "\u0118": rb"\k{E}",
    "\u0119": rb"\k{e}",
    "\u011A": rb"\v{E}",
    "\u011B": rb"\v{e}",
    "\u011C": rb"\^{G}",
    "\u011D": rb"\^{g}",
    "\u011E": rb"\u{G}",
    "\u011F": rb"\u{g}",
    "\u0120": rb"\.{G}",
    "\u0121": rb"\.{g}",
    "\u0122": rb"\c{G}",
    "\u0123": rb"\c{g}",
    "\u0124": rb"\^{H}",
    "\u0125": rb"\^{h}",
    "\u0126": rb"{\fontencoding{LELA}\selectfont\char40}",
    "\u0127": rb"\Elzxh{}",
    "\u0128": rb"\~{I}",
    "\u0129": rb"\~{\i}",
    "\u012A": rb"\={I}",
    "\u012B": rb"\={\i}",
    "\u012C": rb"\u{I}",
    "\u012D": rb"\u{\i}",
    "\u012E": rb"\k{I}",
    "\u012F": rb"\k{i}",
    "\u0130": rb"\.{I}",
    "\u0131": rb"\i{}",
    "\u0132": rb"IJ",
    "\u0133": rb"ij",
    "\u0134": rb"\^{J}",
    "\u0135": rb"\^{\j}",
    "\u0136": rb"\c{K}",
    "\u0137": rb"\c{k}",
    "\u0138": rb"{\fontencoding{LELA}\selectfont\char91}",
    "\u0139": rb"\'{L}",
    "\u013A": rb"\'{l}",
    "\u013B": rb"\c{L}",
    "\u013C": rb"\c{l}",
    "\u013D": rb"\v{L}",
    "\u013E": rb"\v{l}",
    "\u013F": rb"{\fontencoding{LELA}\selectfont\char201}",
    "\u0140": rb"{\fontencoding{LELA}\selectfont\char202}",
    "\u0141": rb"\L{}",
    "\u0142": rb"\l{}",
    "\u0143": rb"\'{N}",
    "\u0144": rb"\'{n}",
    "\u0145": rb"\c{N}",
    "\u0146": rb"\c{n}",
    "\u0147": rb"\v{N}",
    "\u0148": rb"\v{n}",
    "\u0149": rb"'n",
    "\u014A": rb"\NG{}",
    "\u014B": rb"\ng{}",
    "\u014C": rb"\={O}",
    "\u014D": rb"\={o}",
    "\u014E": rb"\u{O}",
    "\u014F": rb"\u{o}",
    "\u0150": rb"\H{O}",
    "\u0151": rb"\H{o}",
    "\u0152": rb"\OE{}",
    "\u0153": rb"\oe{}",
    "\u0154": rb"\'{R}",
    "\u0155": rb"\'{r}",
    "\u0156": rb"\c{R}",
    "\u0157": rb"\c{r}",
    "\u0158": rb"\v{R}",
    "\u0159": rb"\v{r}",
    "\u015A": rb"\'{S}",
    "\u015B": rb"\'{s}",
    "\u015C": rb"\^{S}",
    "\u015D": rb"\^{s}",
    "\u015E": rb"\c{S}",
    "\u015F": rb"\c{s}",
    "\u0160": rb"\v{S}",
    "\u0161": rb"\v{s}",
    "\u0162": rb"\c{T}",
    "\u0163": rb"\c{t}",
    "\u0164": rb"\v{T}",
    "\u0165": rb"\v{t}",
    "\u0166": rb"{\fontencoding{LELA}\selectfont\char47}",
    "\u0167": rb"{\fontencoding{LELA}\selectfont\char63}",
    "\u0168": rb"\~{U}",
    "\u0169": rb"\~{u}",
    "\u016A": rb"\={U}",
    "\u016B": rb"\={u}",
    "\u016C": rb"\u{U}",
    "\u016D": rb"\u{u}",
    "\u016E": rb"\r{U}",
    "\u016F": rb"\r{u}",
    "\u0170": rb"\H{U}",
    "\u0171": rb"\H{u}",
    "\u0172": rb"\k{U}",
    "\u0173": rb"\k{u}",
    "\u0174": rb"\^{W}",
    "\u0175": rb"\^{w}",
    "\u0176": rb"\^{Y}",
    "\u0177": rb"\^{y}",
    "\u0178": rb"\"{Y}",  # note single-quoted string
    "\u0179": rb"\'{Z}",
    "\u017A": rb"\'{z}",
    "\u017B": rb"\.{Z}",
    "\u017C": rb"\.{z}",
    "\u017D": rb"\v{Z}",
    "\u017E": rb"\v{z}",
    "\u0195": rb"\texthvlig{}",
    "\u019E": rb"\textnrleg{}",
    "\u01AA": rb"\eth{}",
    "\u01BA": rb"{\fontencoding{LELA}\selectfont\char195}",
    "\u01C2": rb"\textdoublepipe{}",
    "\u01F5": rb"\'{g}",
    "\u0250": rb"\Elztrna{}",
    "\u0252": rb"\Elztrnsa{}",
    "\u0254": rb"\Elzopeno{}",
    "\u0256": rb"\Elzrtld{}",
    "\u0258": rb"{\fontencoding{LEIP}\selectfont\char61}",
    "\u0259": rb"\Elzschwa{}",
    "\u025B": rb"\varepsilon{}",
    "\u0263": rb"\Elzpgamma{}",
    "\u0264": rb"\Elzpbgam{}",
    "\u0265": rb"\Elztrnh{}",
    "\u026C": rb"\Elzbtdl{}",
    "\u026D": rb"\Elzrtll{}",
    "\u026F": rb"\Elztrnm{}",
    "\u0270": rb"\Elztrnmlr{}",
    "\u0271": rb"\Elzltlmr{}",
    "\u0272": rb"\Elzltln{}",
    "\u0273": rb"\Elzrtln{}",
    "\u0277": rb"\Elzclomeg{}",
    "\u0278": rb"\textphi{}",
    "\u0279": rb"\Elztrnr{}",
    "\u027A": rb"\Elztrnrl{}",
    "\u027B": rb"\Elzrttrnr{}",
    "\u027C": rb"\Elzrl{}",
    "\u027D": rb"\Elzrtlr{}",
    "\u027E": rb"\Elzfhr{}",
    "\u027F": rb"{\fontencoding{LEIP}\selectfont\char202}",
    "\u0282": rb"\Elzrtls{}",
    "\u0283": rb"\Elzesh{}",
    "\u0287": rb"\Elztrnt{}",
    "\u0288": rb"\Elzrtlt{}",
    "\u028A": rb"\Elzpupsil{}",
    "\u028B": rb"\Elzpscrv{}",
    "\u028C": rb"\Elzinvv{}",
    "\u028D": rb"\Elzinvw{}",
    "\u028E": rb"\Elztrny{}",
    "\u0290": rb"\Elzrtlz{}",
    "\u0292": rb"\Elzyogh{}",
    "\u0294": rb"\Elzglst{}",
    "\u0295": rb"\Elzreglst{}",
    "\u0296": rb"\Elzinglst{}",
    "\u029E": rb"\textturnk{}",
    "\u02A4": rb"\Elzdyogh{}",
    "\u02A7": rb"\Elztesh{}",
    "\u02C7": rb"\textasciicaron{}",
    "\u02C8": rb"\Elzverts{}",
    "\u02CC": rb"\Elzverti{}",
    "\u02D0": rb"\Elzlmrk{}",
    "\u02D1": rb"\Elzhlmrk{}",
    "\u02D2": rb"\Elzsbrhr{}",
    "\u02D3": rb"\Elzsblhr{}",
    "\u02D4": rb"\Elzrais{}",
    "\u02D5": rb"\Elzlow{}",
    "\u02D8": rb"\textasciibreve{}",
    "\u02D9": rb"\textperiodcentered{}",
    "\u02DA": rb"\r{}",
    "\u02DB": rb"\k{}",
    "\u02DC": rb"\texttildelow{}",
    "\u02DD": rb"\H{}",
    "\u02E5": rb"\tone{55}",
    "\u02E6": rb"\tone{44}",
    "\u02E7": rb"\tone{33}",
    "\u02E8": rb"\tone{22}",
    "\u02E9": rb"\tone{11}",
    "\u0300": rb"\`",
    "\u0301": rb"\'",
    "\u0302": rb"\^",
    "\u0303": rb"\~",
    "\u0304": rb"\=",
    "\u0306": rb"\u",
    "\u0307": rb"\.",
    "\u0308": rb"\"",  # note single-quoted string
    "\u030A": rb"\r",
    "\u030B": rb"\H",
    "\u030C": rb"\v",
    "\u030F": rb"\cyrchar\C",
    "\u0311": rb"{\fontencoding{LECO}\selectfont\char177}",
    "\u0318": rb"{\fontencoding{LECO}\selectfont\char184}",
    "\u0319": rb"{\fontencoding{LECO}\selectfont\char185}",
    "\u0321": rb"\Elzpalh{}",
    "\u0322": rb"\Elzrh{}",
    "\u0327": rb"\c",
    "\u0328": rb"\k",
    "\u032A": rb"\Elzsbbrg{}",
    "\u032B": rb"{\fontencoding{LECO}\selectfont\char203}",
    "\u032F": rb"{\fontencoding{LECO}\selectfont\char207}",
    "\u0335": rb"\Elzxl{}",
    "\u0336": rb"\Elzbar{}",
    "\u0337": rb"{\fontencoding{LECO}\selectfont\char215}",
    "\u0338": rb"{\fontencoding{LECO}\selectfont\char216}",
    "\u033A": rb"{\fontencoding{LECO}\selectfont\char218}",
    "\u033B": rb"{\fontencoding{LECO}\selectfont\char219}",
    "\u033C": rb"{\fontencoding{LECO}\selectfont\char220}",
    "\u033D": rb"{\fontencoding{LECO}\selectfont\char221}",
    "\u0361": rb"{\fontencoding{LECO}\selectfont\char225}",
    "\u0386": rb"\'{A}",
    "\u0388": rb"\'{E}",
    "\u0389": rb"\'{H}",
    "\u038A": rb"\'{}{I}",
    "\u038C": rb"\'{}O",
    "\u038E": rb"\mathrm{'Y}",
    "\u038F": rb"\mathrm{'\Omega}",
    "\u0390": rb"\acute{\ddot{\iota}}",
    "\u0391": rb"\ensuremath{\Alpha}",
    "\u0392": rb"\ensuremath{\Beta}",
    "\u0393": rb"\ensuremath{\Gamma}",
    "\u0394": rb"\ensuremath{\Delta}",
    "\u0395": rb"\ensuremath{\Epsilon}",
    "\u0396": rb"\ensuremath{\Zeta}",
    "\u0397": rb"\ensuremath{\Eta}",
    "\u0398": rb"\ensuremath{\Theta}",
    "\u0399": rb"\ensuremath{\Iota}",
    "\u039A": rb"\ensuremath{\Kappa}",
    "\u039B": rb"\ensuremath{\Lambda}",
    "\u039E": rb"\ensuremath{\Xi}",
    "\u03A0": rb"\ensuremath{\Pi}",
    "\u03A1": rb"\ensuremath{\Rho}",
    "\u03A3": rb"\ensuremath{\Sigma}",
    "\u03A4": rb"\ensuremath{\Tau}",
    "\u03A5": rb"\ensuremath{\Upsilon}",
    "\u03A6": rb"\ensuremath{\Phi}",
    "\u03A7": rb"\ensuremath{\Chi}",
    "\u03A8": rb"\ensuremath{\Psi}",
    "\u03A9": rb"\ensuremath{\Omega}",
    "\u03AA": rb"\mathrm{\ddot{I}}",
    "\u03AB": rb"\mathrm{\ddot{Y}}",
    "\u03AC": rb"\'{$\alpha$}",
    "\u03AD": rb"\acute{\epsilon}",
    "\u03AE": rb"\acute{\eta}",
    "\u03AF": rb"\acute{\iota}",
    "\u03B0": rb"\acute{\ddot{\upsilon}}",
    "\u03B1": rb"\ensuremath{\alpha}",
    "\u03B2": rb"\ensuremath{\beta}",
    "\u03B3": rb"\ensuremath{\gamma}",
    "\u03B4": rb"\ensuremath{\delta}",
    "\u03B5": rb"\ensuremath{\epsilon}",
    "\u03B6": rb"\ensuremath{\zeta}",
    "\u03B7": rb"\ensuremath{\eta}",
    "\u03B8": rb"\texttheta{}",
    "\u03B9": rb"\ensuremath{\iota}",
    "\u03BA": rb"\ensuremath{\kappa}",
    "\u03BB": rb"\ensuremath{\lambda}",
    "\u03BC": rb"\ensuremath{\mu}",
    "\u03BD": rb"\ensuremath{\nu}",
    "\u03BE": rb"\ensuremath{\xi}",
    "\u03C0": rb"\ensuremath{\pi}",
    "\u03C1": rb"\ensuremath{\rho}",
    "\u03C2": rb"\ensuremath{\varsigma}",
    "\u03C3": rb"\ensuremath{\sigma}",
    "\u03C4": rb"\ensuremath{\tau}",
    "\u03C5": rb"\ensuremath{\upsilon}",
    "\u03C6": rb"\ensuremath{\varphi}",
    "\u03C7": rb"\ensuremath{\chi}",
    "\u03C8": rb"\ensuremath{\psi}",
    "\u03C9": rb"\ensuremath{\omega}",
    "\u03CA": rb"\ensuremath{\ddot{\iota}}",
    "\u03CB": rb"\ensuremath{\ddot{\upsilon}}",
    "\u03CC": rb"\'{o}",
    "\u03CD": rb"\acute{\upsilon}",
    "\u03CE": rb"\acute{\omega}",
    "\u03D0": rb"\Pisymbol{ppi022}{87}",
    "\u03D1": rb"\textvartheta{}",
    "\u03D2": rb"\ensuremath{\Upsilon}",
    "\u03D5": rb"\ensuremath{\phi}",
    "\u03D6": rb"\ensuremath{\varpi}",
    "\u03DA": rb"\Stigma{}",
    "\u03DC": rb"\Digamma{}",
    "\u03DD": rb"\digamma{}",
    "\u03DE": rb"\Koppa{}",
    "\u03E0": rb"\Sampi{}",
    "\u03F0": rb"\varkappa{}",
    "\u03F1": rb"\varrho{}",
    "\u03F4": rb"\textTheta{}",
    "\u03F6": rb"\backepsilon{}",
    "\u0401": rb"\cyrchar\CYRYO{}",
    "\u0402": rb"\cyrchar\CYRDJE{}",
    "\u0403": rb"\cyrchar{\'\CYRG}",
    "\u0404": rb"\cyrchar\CYRIE{}",
    "\u0405": rb"\cyrchar\CYRDZE{}",
    "\u0406": rb"\cyrchar\CYRII{}",
    "\u0407": rb"\cyrchar\CYRYI{}",
    "\u0408": rb"\cyrchar\CYRJE{}",
    "\u0409": rb"\cyrchar\CYRLJE{}",
    "\u040A": rb"\cyrchar\CYRNJE{}",
    "\u040B": rb"\cyrchar\CYRTSHE{}",
    "\u040C": rb"\cyrchar{\'\CYRK}",
    "\u040E": rb"\cyrchar\CYRUSHRT{}",
    "\u040F": rb"\cyrchar\CYRDZHE{}",
    "\u0410": rb"\cyrchar\CYRA{}",
    "\u0411": rb"\cyrchar\CYRB{}",
    "\u0412": rb"\cyrchar\CYRV{}",
    "\u0413": rb"\cyrchar\CYRG{}",
    "\u0414": rb"\cyrchar\CYRD{}",
    "\u0415": rb"\cyrchar\CYRE{}",
    "\u0416": rb"\cyrchar\CYRZH{}",
    "\u0417": rb"\cyrchar\CYRZ{}",
    "\u0418": rb"\cyrchar\CYRI{}",
    "\u0419": rb"\cyrchar\CYRISHRT{}",
    "\u041A": rb"\cyrchar\CYRK{}",
    "\u041B": rb"\cyrchar\CYRL{}",
    "\u041C": rb"\cyrchar\CYRM{}",
    "\u041D": rb"\cyrchar\CYRN{}",
    "\u041E": rb"\cyrchar\CYRO{}",
    "\u041F": rb"\cyrchar\CYRP{}",
    "\u0420": rb"\cyrchar\CYRR{}",
    "\u0421": rb"\cyrchar\CYRS{}",
    "\u0422": rb"\cyrchar\CYRT{}",
    "\u0423": rb"\cyrchar\CYRU{}",
    "\u0424": rb"\cyrchar\CYRF{}",
    "\u0425": rb"\cyrchar\CYRH{}",
    "\u0426": rb"\cyrchar\CYRC{}",
    "\u0427": rb"\cyrchar\CYRCH{}",
    "\u0428": rb"\cyrchar\CYRSH{}",
    "\u0429": rb"\cyrchar\CYRSHCH{}",
    "\u042A": rb"\cyrchar\CYRHRDSN{}",
    "\u042B": rb"\cyrchar\CYRERY{}",
    "\u042C": rb"\cyrchar\CYRSFTSN{}",
    "\u042D": rb"\cyrchar\CYREREV{}",
    "\u042E": rb"\cyrchar\CYRYU{}",
    "\u042F": rb"\cyrchar\CYRYA{}",
    "\u0430": rb"\cyrchar\cyra{}",
    "\u0431": rb"\cyrchar\cyrb{}",
    "\u0432": rb"\cyrchar\cyrv{}",
    "\u0433": rb"\cyrchar\cyrg{}",
    "\u0434": rb"\cyrchar\cyrd{}",
    "\u0435": rb"\cyrchar\cyre{}",
    "\u0436": rb"\cyrchar\cyrzh{}",
    "\u0437": rb"\cyrchar\cyrz{}",
    "\u0438": rb"\cyrchar\cyri{}",
    "\u0439": rb"\cyrchar\cyrishrt{}",
    "\u043A": rb"\cyrchar\cyrk{}",
    "\u043B": rb"\cyrchar\cyrl{}",
    "\u043C": rb"\cyrchar\cyrm{}",
    "\u043D": rb"\cyrchar\cyrn{}",
    "\u043E": rb"\cyrchar\cyro{}",
    "\u043F": rb"\cyrchar\cyrp{}",
    "\u0440": rb"\cyrchar\cyrr{}",
    "\u0441": rb"\cyrchar\cyrs{}",
    "\u0442": rb"\cyrchar\cyrt{}",
    "\u0443": rb"\cyrchar\cyru{}",
    "\u0444": rb"\cyrchar\cyrf{}",
    "\u0445": rb"\cyrchar\cyrh{}",
    "\u0446": rb"\cyrchar\cyrc{}",
    "\u0447": rb"\cyrchar\cyrch{}",
    "\u0448": rb"\cyrchar\cyrsh{}",
    "\u0449": rb"\cyrchar\cyrshch{}",
    "\u044A": rb"\cyrchar\cyrhrdsn{}",
    "\u044B": rb"\cyrchar\cyrery{}",
    "\u044C": rb"\cyrchar\cyrsftsn{}",
    "\u044D": rb"\cyrchar\cyrerev{}",
    "\u044E": rb"\cyrchar\cyryu{}",
    "\u044F": rb"\cyrchar\cyrya{}",
    "\u0451": rb"\cyrchar\cyryo{}",
    "\u0452": rb"\cyrchar\cyrdje{}",
    "\u0453": rb"\cyrchar{\'\cyrg}",
    "\u0454": rb"\cyrchar\cyrie{}",
    "\u0455": rb"\cyrchar\cyrdze{}",
    "\u0456": rb"\cyrchar\cyrii{}",
    "\u0457": rb"\cyrchar\cyryi{}",
    "\u0458": rb"\cyrchar\cyrje{}",
    "\u0459": rb"\cyrchar\cyrlje{}",
    "\u045A": rb"\cyrchar\cyrnje{}",
    "\u045B": rb"\cyrchar\cyrtshe{}",
    "\u045C": rb"\cyrchar{\'\cyrk}",
    "\u045E": rb"\cyrchar\cyrushrt{}",
    "\u045F": rb"\cyrchar\cyrdzhe{}",
    "\u0460": rb"\cyrchar\CYROMEGA{}",
    "\u0461": rb"\cyrchar\cyromega{}",
    "\u0462": rb"\cyrchar\CYRYAT{}",
    "\u0464": rb"\cyrchar\CYRIOTE{}",
    "\u0465": rb"\cyrchar\cyriote{}",
    "\u0466": rb"\cyrchar\CYRLYUS{}",
    "\u0467": rb"\cyrchar\cyrlyus{}",
    "\u0468": rb"\cyrchar\CYRIOTLYUS{}",
    "\u0469": rb"\cyrchar\cyriotlyus{}",
    "\u046A": rb"\cyrchar\CYRBYUS{}",
    "\u046C": rb"\cyrchar\CYRIOTBYUS{}",
    "\u046D": rb"\cyrchar\cyriotbyus{}",
    "\u046E": rb"\cyrchar\CYRKSI{}",
    "\u046F": rb"\cyrchar\cyrksi{}",
    "\u0470": rb"\cyrchar\CYRPSI{}",
    "\u0471": rb"\cyrchar\cyrpsi{}",
    "\u0472": rb"\cyrchar\CYRFITA{}",
    "\u0474": rb"\cyrchar\CYRIZH{}",
    "\u0478": rb"\cyrchar\CYRUK{}",
    "\u0479": rb"\cyrchar\cyruk{}",
    "\u047A": rb"\cyrchar\CYROMEGARND{}",
    "\u047B": rb"\cyrchar\cyromegarnd{}",
    "\u047C": rb"\cyrchar\CYROMEGATITLO{}",
    "\u047D": rb"\cyrchar\cyromegatitlo{}",
    "\u047E": rb"\cyrchar\CYROT{}",
    "\u047F": rb"\cyrchar\cyrot{}",
    "\u0480": rb"\cyrchar\CYRKOPPA{}",
    "\u0481": rb"\cyrchar\cyrkoppa{}",
    "\u0482": rb"\cyrchar\cyrthousands{}",
    "\u0488": rb"\cyrchar\cyrhundredthousands{}",
    "\u0489": rb"\cyrchar\cyrmillions{}",
    "\u048C": rb"\cyrchar\CYRSEMISFTSN{}",
    "\u048D": rb"\cyrchar\cyrsemisftsn{}",
    "\u048E": rb"\cyrchar\CYRRTICK{}",
    "\u048F": rb"\cyrchar\cyrrtick{}",
    "\u0490": rb"\cyrchar\CYRGUP{}",
    "\u0491": rb"\cyrchar\cyrgup{}",
    "\u0492": rb"\cyrchar\CYRGHCRS{}",
    "\u0493": rb"\cyrchar\cyrghcrs{}",
    "\u0494": rb"\cyrchar\CYRGHK{}",
    "\u0495": rb"\cyrchar\cyrghk{}",
    "\u0496": rb"\cyrchar\CYRZHDSC{}",
    "\u0497": rb"\cyrchar\cyrzhdsc{}",
    "\u0498": rb"\cyrchar\CYRZDSC{}",
    "\u0499": rb"\cyrchar\cyrzdsc{}",
    "\u049A": rb"\cyrchar\CYRKDSC{}",
    "\u049B": rb"\cyrchar\cyrkdsc{}",
    "\u049C": rb"\cyrchar\CYRKVCRS{}",
    "\u049D": rb"\cyrchar\cyrkvcrs{}",
    "\u049E": rb"\cyrchar\CYRKHCRS{}",
    "\u049F": rb"\cyrchar\cyrkhcrs{}",
    "\u04A0": rb"\cyrchar\CYRKBEAK{}",
    "\u04A1": rb"\cyrchar\cyrkbeak{}",
    "\u04A2": rb"\cyrchar\CYRNDSC{}",
    "\u04A3": rb"\cyrchar\cyrndsc{}",
    "\u04A4": rb"\cyrchar\CYRNG{}",
    "\u04A5": rb"\cyrchar\cyrng{}",
    "\u04A6": rb"\cyrchar\CYRPHK{}",
    "\u04A7": rb"\cyrchar\cyrphk{}",
    "\u04A8": rb"\cyrchar\CYRABHHA{}",
    "\u04A9": rb"\cyrchar\cyrabhha{}",
    "\u04AA": rb"\cyrchar\CYRSDSC{}",
    "\u04AB": rb"\cyrchar\cyrsdsc{}",
    "\u04AC": rb"\cyrchar\CYRTDSC{}",
    "\u04AD": rb"\cyrchar\cyrtdsc{}",
    "\u04AE": rb"\cyrchar\CYRY{}",
    "\u04AF": rb"\cyrchar\cyry{}",
    "\u04B0": rb"\cyrchar\CYRYHCRS{}",
    "\u04B1": rb"\cyrchar\cyryhcrs{}",
    "\u04B2": rb"\cyrchar\CYRHDSC{}",
    "\u04B3": rb"\cyrchar\cyrhdsc{}",
    "\u04B4": rb"\cyrchar\CYRTETSE{}",
    "\u04B5": rb"\cyrchar\cyrtetse{}",
    "\u04B6": rb"\cyrchar\CYRCHRDSC{}",
    "\u04B7": rb"\cyrchar\cyrchrdsc{}",
    "\u04B8": rb"\cyrchar\CYRCHVCRS{}",
    "\u04B9": rb"\cyrchar\cyrchvcrs{}",
    "\u04BA": rb"\cyrchar\CYRSHHA{}",
    "\u04BB": rb"\cyrchar\cyrshha{}",
    "\u04BC": rb"\cyrchar\CYRABHCH{}",
    "\u04BD": rb"\cyrchar\cyrabhch{}",
    "\u04BE": rb"\cyrchar\CYRABHCHDSC{}",
    "\u04BF": rb"\cyrchar\cyrabhchdsc{}",
    "\u04C0": rb"\cyrchar\CYRpalochka{}",
    "\u04C3": rb"\cyrchar\CYRKHK{}",
    "\u04C4": rb"\cyrchar\cyrkhk{}",
    "\u04C7": rb"\cyrchar\CYRNHK{}",
    "\u04C8": rb"\cyrchar\cyrnhk{}",
    "\u04CB": rb"\cyrchar\CYRCHLDSC{}",
    "\u04CC": rb"\cyrchar\cyrchldsc{}",
    "\u04D4": rb"\cyrchar\CYRAE{}",
    "\u04D5": rb"\cyrchar\cyrae{}",
    "\u04D8": rb"\cyrchar\CYRSCHWA{}",
    "\u04D9": rb"\cyrchar\cyrschwa{}",
    "\u04E0": rb"\cyrchar\CYRABHDZE{}",
    "\u04E1": rb"\cyrchar\cyrabhdze{}",
    "\u04E8": rb"\cyrchar\CYROTLD{}",
    "\u04E9": rb"\cyrchar\cyrotld{}",
    "\u2002": rb"\hspace{0.6em}",
    "\u2003": rb"\hspace{1em}",
    "\u2004": rb"\hspace{0.33em}",
    "\u2005": rb"\hspace{0.25em}",
    "\u2006": rb"\hspace{0.166em}",
    "\u2007": rb"\hphantom{0}",
    "\u2008": rb"\hphantom{,}",
    "\u2009": rb"\hspace{0.167em}",
    "\u200A": rb"\mkern1mu{}",
    "\u2010": rb"-",
    "\u2013": rb"\textendash{}",
    "\u2014": rb"\textemdash{}",
    "\u2015": rb"\rule{1em}{1pt}",
    "\u2016": rb"\Vert{}",
    "\u2018": rb"`",
    "\u2019": rb"'",
    "\u201B": rb"\Elzreapos{}",
    "\u201C": rb"\textquotedblleft{}",
    "\u201D": rb"\textquotedblright{}",
    "\u201E": rb",,",
    "\u2020": rb"\textdagger{}",
    "\u2021": rb"\textdaggerdbl{}",
    "\u2022": rb"\textbullet{}",
    "\u2025": rb"..",
    "\u2026": rb"\ldots{}",
    "\u2030": rb"\textperthousand{}",
    "\u2031": rb"\textpertenthousand{}",
    "\u2032": rb"\ensuremath{'}",
    "\u2033": rb"\ensuremath{''}",
    "\u2034": rb"\ensuremath{'''}",
    "\u2035": rb"\backprime{}",
    "\u2039": rb"\guilsinglleft{}",
    "\u203A": rb"\guilsinglright{}",
    "\u2057": rb"''''",
    "\u205F": rb"\mkern4mu{}",
    "\u2060": rb"\nolinebreak{}",
    "\u20A7": rb"\ensuremath{\Elzpes}",
    "\u20AC": rb"\mbox{\texteuro}{}",
    "\u20DB": rb"\dddot{}",
    "\u20DC": rb"\ddddot{}",
    "\u2102": rb"\mathbb{C}",
    "\u210A": rb"\mathscr{g}",
    "\u210B": rb"\mathscr{H}",
    "\u210C": rb"\mathfrak{H}",
    "\u210D": rb"\mathbb{H}",
    "\u210F": rb"\hslash{}",
    "\u2110": rb"\mathscr{I}",
    "\u2111": rb"\mathfrak{I}",
    "\u2112": rb"\mathscr{L}",
    "\u2113": rb"\mathscr{l}",
    "\u2115": rb"\mathbb{N}",
    "\u2116": rb"\cyrchar\textnumero{}",
    "\u2118": rb"\wp{}",
    "\u2119": rb"\mathbb{P}",
    "\u211A": rb"\mathbb{Q}",
    "\u211B": rb"\mathscr{R}",
    "\u211C": rb"\mathfrak{R}",
    "\u211D": rb"\mathbb{R}",
    "\u211E": rb"\Elzxrat{}",
    "\u2122": rb"\texttrademark{}",
    "\u2124": rb"\mathbb{Z}",
    "\u2126": rb"\Omega{}",
    "\u2127": rb"\mho{}",
    "\u2128": rb"\mathfrak{Z}",
    "\u2129": rb"\ElsevierGlyph{2129}",
    "\u212B": rb"\AA{}",
    "\u212C": rb"\mathscr{B}",
    "\u212D": rb"\mathfrak{C}",
    "\u212F": rb"\mathscr{e}",
    "\u2130": rb"\mathscr{E}",
    "\u2131": rb"\mathscr{F}",
    "\u2133": rb"\mathscr{M}",
    "\u2134": rb"\mathscr{o}",
    "\u2135": rb"\aleph{}",
    "\u2136": rb"\beth{}",
    "\u2137": rb"\gimel{}",
    "\u2138": rb"\daleth{}",
    "\u2153": rb"\textfrac{1}{3}",
    "\u2154": rb"\textfrac{2}{3}",
    "\u2155": rb"\textfrac{1}{5}",
    "\u2156": rb"\textfrac{2}{5}",
    "\u2157": rb"\textfrac{3}{5}",
    "\u2158": rb"\textfrac{4}{5}",
    "\u2159": rb"\textfrac{1}{6}",
    "\u215A": rb"\textfrac{5}{6}",
    "\u215B": rb"\textfrac{1}{8}",
    "\u215C": rb"\textfrac{3}{8}",
    "\u215D": rb"\textfrac{5}{8}",
    "\u215E": rb"\textfrac{7}{8}",
    "\u2190": rb"\leftarrow{}",
    "\u2191": rb"\uparrow{}",
    "\u2192": rb"\rightarrow{}",
    "\u2193": rb"\downarrow{}",
    "\u2194": rb"\leftrightarrow{}",
    "\u2195": rb"\updownarrow{}",
    "\u2196": rb"\nwarrow{}",
    "\u2197": rb"\nearrow{}",
    "\u2198": rb"\searrow{}",
    "\u2199": rb"\swarrow{}",
    "\u219A": rb"\nleftarrow{}",
    "\u219B": rb"\nrightarrow{}",
    "\u219C": rb"\arrowwaveright{}",
    "\u219D": rb"\arrowwaveright{}",
    "\u219E": rb"\twoheadleftarrow{}",
    "\u21A0": rb"\twoheadrightarrow{}",
    "\u21A2": rb"\leftarrowtail{}",
    "\u21A3": rb"\rightarrowtail{}",
    "\u21A6": rb"\mapsto{}",
    "\u21A9": rb"\hookleftarrow{}",
    "\u21AA": rb"\hookrightarrow{}",
    "\u21AB": rb"\looparrowleft{}",
    "\u21AC": rb"\looparrowright{}",
    "\u21AD": rb"\leftrightsquigarrow{}",
    "\u21AE": rb"\nleftrightarrow{}",
    "\u21B0": rb"\Lsh{}",
    "\u21B1": rb"\Rsh{}",
    "\u21B3": rb"\ElsevierGlyph{21B3}",
    "\u21B6": rb"\curvearrowleft{}",
    "\u21B7": rb"\curvearrowright{}",
    "\u21BA": rb"\circlearrowleft{}",
    "\u21BB": rb"\circlearrowright{}",
    "\u21BC": rb"\leftharpoonup{}",
    "\u21BD": rb"\leftharpoondown{}",
    "\u21BE": rb"\upharpoonright{}",
    "\u21BF": rb"\upharpoonleft{}",
    "\u21C0": rb"\rightharpoonup{}",
    "\u21C1": rb"\rightharpoondown{}",
    "\u21C2": rb"\downharpoonright{}",
    "\u21C3": rb"\downharpoonleft{}",
    "\u21C4": rb"\rightleftarrows{}",
    "\u21C5": rb"\dblarrowupdown{}",
    "\u21C6": rb"\leftrightarrows{}",
    "\u21C7": rb"\leftleftarrows{}",
    "\u21C8": rb"\upuparrows{}",
    "\u21C9": rb"\rightrightarrows{}",
    "\u21CA": rb"\downdownarrows{}",
    "\u21CB": rb"\leftrightharpoons{}",
    "\u21CC": rb"\rightleftharpoons{}",
    "\u21CD": rb"\nLeftarrow{}",
    "\u21CE": rb"\nLeftrightarrow{}",
    "\u21CF": rb"\nRightarrow{}",
    "\u21D0": rb"\Leftarrow{}",
    "\u21D1": rb"\Uparrow{}",
    "\u21D2": rb"\Rightarrow{}",
    "\u21D3": rb"\Downarrow{}",
    "\u21D4": rb"\Leftrightarrow{}",
    "\u21D5": rb"\Updownarrow{}",
    "\u21DA": rb"\Lleftarrow{}",
    "\u21DB": rb"\Rrightarrow{}",
    "\u21DD": rb"\rightsquigarrow{}",
    "\u21F5": rb"\DownArrowUpArrow{}",
    "\u2200": rb"\forall{}",
    "\u2201": rb"\complement{}",
    "\u2202": rb"\partial{}",
    "\u2203": rb"\exists{}",
    "\u2204": rb"\nexists{}",
    "\u2205": rb"\varnothing{}",
    "\u2207": rb"\nabla{}",
    "\u2208": rb"\in{}",
    "\u2209": rb"\not\in{}",
    "\u220B": rb"\ni{}",
    "\u220C": rb"\not\ni{}",
    "\u220F": rb"\prod{}",
    "\u2210": rb"\coprod{}",
    "\u2211": rb"\sum{}",
    "\u2213": rb"\mp{}",
    "\u2214": rb"\dotplus{}",
    "\u2216": rb"\setminus{}",
    "\u2217": rb"{_\ast}",
    "\u2218": rb"\circ{}",
    "\u2219": rb"\bullet{}",
    "\u221A": rb"\surd{}",
    "\u221D": rb"\propto{}",
    "\u221E": rb"\infty{}",
    "\u221F": rb"\rightangle{}",
    "\u2220": rb"\angle{}",
    "\u2221": rb"\measuredangle{}",
    "\u2222": rb"\sphericalangle{}",
    "\u2223": rb"\mid{}",
    "\u2224": rb"\nmid{}",
    "\u2225": rb"\parallel{}",
    "\u2226": rb"\nparallel{}",
    "\u2227": rb"\wedge{}",
    "\u2228": rb"\vee{}",
    "\u2229": rb"\cap{}",
    "\u222A": rb"\cup{}",
    "\u222B": rb"\int{}",
    "\u222C": rb"\int\!\int{}",
    "\u222D": rb"\int\!\int\!\int{}",
    "\u222E": rb"\oint{}",
    "\u222F": rb"\surfintegral{}",
    "\u2230": rb"\volintegral{}",
    "\u2231": rb"\clwintegral{}",
    "\u2232": rb"\ElsevierGlyph{2232}",
    "\u2233": rb"\ElsevierGlyph{2233}",
    "\u2234": rb"\therefore{}",
    "\u2235": rb"\because{}",
    "\u2237": rb"\Colon{}",
    "\u2238": rb"\ElsevierGlyph{2238}",
    "\u223A": rb"\mathbin{{:}\!\!{-}\!\!{:}}",
    "\u223B": rb"\homothetic{}",
    "\u223C": rb"\sim{}",
    "\u223D": rb"\backsim{}",
    "\u223E": rb"\lazysinv{}",
    "\u2240": rb"\wr{}",
    "\u2241": rb"\not\sim{}",
    "\u2242": rb"\ElsevierGlyph{2242}",
    "\u2243": rb"\simeq{}",
    "\u2244": rb"\not\simeq{}",
    "\u2245": rb"\cong{}",
    "\u2246": rb"\approxnotequal{}",
    "\u2247": rb"\not\cong{}",
    "\u2248": rb"\approx{}",
    "\u2249": rb"\not\approx{}",
    "\u224A": rb"\approxeq{}",
    "\u224B": rb"\tildetrpl{}",
    "\u224C": rb"\allequal{}",
    "\u224D": rb"\asymp{}",
    "\u224E": rb"\Bumpeq{}",
    "\u224F": rb"\bumpeq{}",
    "\u2250": rb"\doteq{}",
    "\u2251": rb"\doteqdot{}",
    "\u2252": rb"\fallingdotseq{}",
    "\u2253": rb"\risingdotseq{}",
    "\u2254": rb":=",
    "\u2255": rb"=:",
    "\u2256": rb"\eqcirc{}",
    "\u2257": rb"\circeq{}",
    "\u2259": rb"\estimates{}",
    "\u225A": rb"\ElsevierGlyph{225A}",
    "\u225B": rb"\starequal{}",
    "\u225C": rb"\triangleq{}",
    "\u225F": rb"\ElsevierGlyph{225F}",
    "\u2260": rb"\not =",
    "\u2261": rb"\equiv{}",
    "\u2262": rb"\not\equiv{}",
    "\u2264": rb"\leq{}",
    "\u2265": rb"\geq{}",
    "\u2266": rb"\leqq{}",
    "\u2267": rb"\geqq{}",
    "\u2268": rb"\lneqq{}",
    "\u2269": rb"\gneqq{}",
    "\u226A": rb"\ll{}",
    "\u226B": rb"\gg{}",
    "\u226C": rb"\between{}",
    "\u226D": rb"\not\kern-0.3em\times{}",
    "\u226E": rb"\not<",
    "\u226F": rb"\not>",
    "\u2270": rb"\not\leq{}",
    "\u2271": rb"\not\geq{}",
    "\u2272": rb"\lessequivlnt{}",
    "\u2273": rb"\greaterequivlnt{}",
    "\u2274": rb"\ElsevierGlyph{2274}",
    "\u2275": rb"\ElsevierGlyph{2275}",
    "\u2276": rb"\lessgtr{}",
    "\u2277": rb"\gtrless{}",
    "\u2278": rb"\notlessgreater{}",
    "\u2279": rb"\notgreaterless{}",
    "\u227A": rb"\prec{}",
    "\u227B": rb"\succ{}",
    "\u227C": rb"\preccurlyeq{}",
    "\u227D": rb"\succcurlyeq{}",
    "\u227E": rb"\precapprox{}",
    "\u227F": rb"\succapprox{}",
    "\u2280": rb"\not\prec{}",
    "\u2281": rb"\not\succ{}",
    "\u2282": rb"\subset{}",
    "\u2283": rb"\supset{}",
    "\u2284": rb"\not\subset{}",
    "\u2285": rb"\not\supset{}",
    "\u2286": rb"\subseteq{}",
    "\u2287": rb"\supseteq{}",
    "\u2288": rb"\not\subseteq{}",
    "\u2289": rb"\not\supseteq{}",
    "\u228A": rb"\subsetneq{}",
    "\u228B": rb"\supsetneq{}",
    "\u228E": rb"\uplus{}",
    "\u228F": rb"\sqsubset{}",
    "\u2290": rb"\sqsupset{}",
    "\u2291": rb"\sqsubseteq{}",
    "\u2292": rb"\sqsupseteq{}",
    "\u2293": rb"\sqcap{}",
    "\u2294": rb"\sqcup{}",
    "\u2295": rb"\oplus{}",
    "\u2296": rb"\ominus{}",
    "\u2297": rb"\otimes{}",
    "\u2298": rb"\oslash{}",
    "\u2299": rb"\odot{}",
    "\u229A": rb"\circledcirc{}",
    "\u229B": rb"\circledast{}",
    "\u229D": rb"\circleddash{}",
    "\u229E": rb"\boxplus{}",
    "\u229F": rb"\boxminus{}",
    "\u22A0": rb"\boxtimes{}",
    "\u22A1": rb"\boxdot{}",
    "\u22A2": rb"\vdash{}",
    "\u22A3": rb"\dashv{}",
    "\u22A4": rb"\top{}",
    "\u22A5": rb"\perp{}",
    "\u22A7": rb"\truestate{}",
    "\u22A8": rb"\forcesextra{}",
    "\u22A9": rb"\Vdash{}",
    "\u22AA": rb"\Vvdash{}",
    "\u22AB": rb"\VDash{}",
    "\u22AC": rb"\nvdash{}",
    "\u22AD": rb"\nvDash{}",
    "\u22AE": rb"\nVdash{}",
    "\u22AF": rb"\nVDash{}",
    "\u22B2": rb"\vartriangleleft{}",
    "\u22B3": rb"\vartriangleright{}",
    "\u22B4": rb"\trianglelefteq{}",
    "\u22B5": rb"\trianglerighteq{}",
    "\u22B6": rb"\original{}",
    "\u22B7": rb"\image{}",
    "\u22B8": rb"\multimap{}",
    "\u22B9": rb"\hermitconjmatrix{}",
    "\u22BA": rb"\intercal{}",
    "\u22BB": rb"\veebar{}",
    "\u22BE": rb"\rightanglearc{}",
    "\u22C0": rb"\ElsevierGlyph{22C0}",
    "\u22C1": rb"\ElsevierGlyph{22C1}",
    "\u22C2": rb"\bigcap{}",
    "\u22C3": rb"\bigcup{}",
    "\u22C4": rb"\diamond{}",
    "\u22C5": rb"\cdot{}",
    "\u22C6": rb"\star{}",
    "\u22C7": rb"\divideontimes{}",
    "\u22C8": rb"\bowtie{}",
    "\u22C9": rb"\ltimes{}",
    "\u22CA": rb"\rtimes{}",
    "\u22CB": rb"\leftthreetimes{}",
    "\u22CC": rb"\rightthreetimes{}",
    "\u22CD": rb"\backsimeq{}",
    "\u22CE": rb"\curlyvee{}",
    "\u22CF": rb"\curlywedge{}",
    "\u22D0": rb"\Subset{}",
    "\u22D1": rb"\Supset{}",
    "\u22D2": rb"\Cap{}",
    "\u22D3": rb"\Cup{}",
    "\u22D4": rb"\pitchfork{}",
    "\u22D6": rb"\lessdot{}",
    "\u22D7": rb"\gtrdot{}",
    "\u22D8": rb"\verymuchless{}",
    "\u22D9": rb"\verymuchgreater{}",
    "\u22DA": rb"\lesseqgtr{}",
    "\u22DB": rb"\gtreqless{}",
    "\u22DE": rb"\curlyeqprec{}",
    "\u22DF": rb"\curlyeqsucc{}",
    "\u22E2": rb"\not\sqsubseteq{}",
    "\u22E3": rb"\not\sqsupseteq{}",
    "\u22E5": rb"\Elzsqspne{}",
    "\u22E6": rb"\lnsim{}",
    "\u22E7": rb"\gnsim{}",
    "\u22E8": rb"\precedesnotsimilar{}",
    "\u22E9": rb"\succnsim{}",
    "\u22EA": rb"\ntriangleleft{}",
    "\u22EB": rb"\ntriangleright{}",
    "\u22EC": rb"\ntrianglelefteq{}",
    "\u22ED": rb"\ntrianglerighteq{}",
    "\u22EE": rb"\vdots{}",
    "\u22EF": rb"\cdots{}",
    "\u22F0": rb"\upslopeellipsis{}",
    "\u22F1": rb"\downslopeellipsis{}",
    "\u2305": rb"\barwedge{}",
    "\u2306": rb"\perspcorrespond{}",
    "\u2308": rb"\lceil{}",
    "\u2309": rb"\rceil{}",
    "\u230A": rb"\lfloor{}",
    "\u230B": rb"\rfloor{}",
    "\u2315": rb"\recorder{}",
    "\u2316": rb'\mathchar"2208',  # note single-quoted string
    "\u231C": rb"\ulcorner{}",
    "\u231D": rb"\urcorner{}",
    "\u231E": rb"\llcorner{}",
    "\u231F": rb"\lrcorner{}",
    "\u2322": rb"\frown{}",
    "\u2323": rb"\smile{}",
    "\u2329": rb"\langle{}",
    "\u232A": rb"\rangle{}",
    "\u233D": rb"\ElsevierGlyph{E838}",
    "\u23A3": rb"\Elzdlcorn{}",
    "\u23B0": rb"\lmoustache{}",
    "\u23B1": rb"\rmoustache{}",
    "\u2423": rb"\textvisiblespace{}",
    "\u2460": rb"\ding{172}",
    "\u2461": rb"\ding{173}",
    "\u2462": rb"\ding{174}",
    "\u2463": rb"\ding{175}",
    "\u2464": rb"\ding{176}",
    "\u2465": rb"\ding{177}",
    "\u2466": rb"\ding{178}",
    "\u2467": rb"\ding{179}",
    "\u2468": rb"\ding{180}",
    "\u2469": rb"\ding{181}",
    "\u24C8": rb"\circledS{}",
    "\u2506": rb"\Elzdshfnc{}",
    "\u2519": rb"\Elzsqfnw{}",
    "\u2571": rb"\diagup{}",
    "\u25A0": rb"\ding{110}",
    "\u25A1": rb"\square{}",
    "\u25AA": rb"\blacksquare{}",
    "\u25AD": rb"\fbox{~~}",
    "\u25AF": rb"\Elzvrecto{}",
    "\u25B1": rb"\ElsevierGlyph{E381}",
    "\u25B2": rb"\ding{115}",
    "\u25B3": rb"\bigtriangleup{}",
    "\u25B4": rb"\blacktriangle{}",
    "\u25B5": rb"\vartriangle{}",
    "\u25B8": rb"\blacktriangleright{}",
    "\u25B9": rb"\triangleright{}",
    "\u25BC": rb"\ding{116}",
    "\u25BD": rb"\bigtriangledown{}",
    "\u25BE": rb"\blacktriangledown{}",
    "\u25BF": rb"\triangledown{}",
    "\u25C2": rb"\blacktriangleleft{}",
    "\u25C3": rb"\triangleleft{}",
    "\u25C6": rb"\ding{117}",
    "\u25CA": rb"\lozenge{}",
    "\u25CB": rb"\bigcirc{}",
    "\u25CF": rb"\ding{108}",
    "\u25D0": rb"\Elzcirfl{}",
    "\u25D1": rb"\Elzcirfr{}",
    "\u25D2": rb"\Elzcirfb{}",
    "\u25D7": rb"\ding{119}",
    "\u25D8": rb"\Elzrvbull{}",
    "\u25E7": rb"\Elzsqfl{}",
    "\u25E8": rb"\Elzsqfr{}",
    "\u25EA": rb"\Elzsqfse{}",
    "\u25EF": rb"\bigcirc{}",
    "\u2605": rb"\ding{72}",
    "\u2606": rb"\ding{73}",
    "\u260E": rb"\ding{37}",
    "\u261B": rb"\ding{42}",
    "\u261E": rb"\ding{43}",
    "\u263E": rb"\rightmoon{}",
    "\u263F": rb"\mercury{}",
    "\u2640": rb"\venus{}",
    "\u2642": rb"\male{}",
    "\u2643": rb"\jupiter{}",
    "\u2644": rb"\saturn{}",
    "\u2645": rb"\uranus{}",
    "\u2646": rb"\neptune{}",
    "\u2647": rb"\pluto{}",
    "\u2648": rb"\aries{}",
    "\u2649": rb"\taurus{}",
    "\u264A": rb"\gemini{}",
    "\u264B": rb"\cancer{}",
    "\u264C": rb"\leo{}",
    "\u264D": rb"\virgo{}",
    "\u264E": rb"\libra{}",
    "\u264F": rb"\scorpio{}",
    "\u2650": rb"\sagittarius{}",
    "\u2651": rb"\capricornus{}",
    "\u2652": rb"\aquarius{}",
    "\u2653": rb"\pisces{}",
    "\u2660": rb"\ding{171}",
    "\u2662": rb"\diamond{}",
    "\u2663": rb"\ding{168}",
    "\u2665": rb"\ding{170}",
    "\u2666": rb"\ding{169}",
    "\u2669": rb"\quarternote{}",
    "\u266A": rb"\eighthnote{}",
    "\u266D": rb"\flat{}",
    "\u266E": rb"\natural{}",
    "\u266F": rb"\sharp{}",
    "\u2701": rb"\ding{33}",
    "\u2702": rb"\ding{34}",
    "\u2703": rb"\ding{35}",
    "\u2704": rb"\ding{36}",
    "\u2706": rb"\ding{38}",
    "\u2707": rb"\ding{39}",
    "\u2708": rb"\ding{40}",
    "\u2709": rb"\ding{41}",
    "\u270C": rb"\ding{44}",
    "\u270D": rb"\ding{45}",
    "\u270E": rb"\ding{46}",
    "\u270F": rb"\ding{47}",
    "\u2710": rb"\ding{48}",
    "\u2711": rb"\ding{49}",
    "\u2712": rb"\ding{50}",
    "\u2713": rb"\ding{51}",
    "\u2714": rb"\ding{52}",
    "\u2715": rb"\ding{53}",
    "\u2716": rb"\ding{54}",
    "\u2717": rb"\ding{55}",
    "\u2718": rb"\ding{56}",
    "\u2719": rb"\ding{57}",
    "\u271A": rb"\ding{58}",
    "\u271B": rb"\ding{59}",
    "\u271C": rb"\ding{60}",
    "\u271D": rb"\ding{61}",
    "\u271E": rb"\ding{62}",
    "\u271F": rb"\ding{63}",
    "\u2720": rb"\ding{64}",
    "\u2721": rb"\ding{65}",
    "\u2722": rb"\ding{66}",
    "\u2723": rb"\ding{67}",
    "\u2724": rb"\ding{68}",
    "\u2725": rb"\ding{69}",
    "\u2726": rb"\ding{70}",
    "\u2727": rb"\ding{71}",
    "\u2729": rb"\ding{73}",
    "\u272A": rb"\ding{74}",
    "\u272B": rb"\ding{75}",
    "\u272C": rb"\ding{76}",
    "\u272D": rb"\ding{77}",
    "\u272E": rb"\ding{78}",
    "\u272F": rb"\ding{79}",
    "\u2730": rb"\ding{80}",
    "\u2731": rb"\ding{81}",
    "\u2732": rb"\ding{82}",
    "\u2733": rb"\ding{83}",
    "\u2734": rb"\ding{84}",
    "\u2735": rb"\ding{85}",
    "\u2736": rb"\ding{86}",
    "\u2737": rb"\ding{87}",
    "\u2738": rb"\ding{88}",
    "\u2739": rb"\ding{89}",
    "\u273A": rb"\ding{90}",
    "\u273B": rb"\ding{91}",
    "\u273C": rb"\ding{92}",
    "\u273D": rb"\ding{93}",
    "\u273E": rb"\ding{94}",
    "\u273F": rb"\ding{95}",
    "\u2740": rb"\ding{96}",
    "\u2741": rb"\ding{97}",
    "\u2742": rb"\ding{98}",
    "\u2743": rb"\ding{99}",
    "\u2744": rb"\ding{100}",
    "\u2745": rb"\ding{101}",
    "\u2746": rb"\ding{102}",
    "\u2747": rb"\ding{103}",
    "\u2748": rb"\ding{104}",
    "\u2749": rb"\ding{105}",
    "\u274A": rb"\ding{106}",
    "\u274B": rb"\ding{107}",
    "\u274D": rb"\ding{109}",
    "\u274F": rb"\ding{111}",
    "\u2750": rb"\ding{112}",
    "\u2751": rb"\ding{113}",
    "\u2752": rb"\ding{114}",
    "\u2756": rb"\ding{118}",
    "\u2758": rb"\ding{120}",
    "\u2759": rb"\ding{121}",
    "\u275A": rb"\ding{122}",
    "\u275B": rb"\ding{123}",
    "\u275C": rb"\ding{124}",
    "\u275D": rb"\ding{125}",
    "\u275E": rb"\ding{126}",
    "\u2761": rb"\ding{161}",
    "\u2762": rb"\ding{162}",
    "\u2763": rb"\ding{163}",
    "\u2764": rb"\ding{164}",
    "\u2765": rb"\ding{165}",
    "\u2766": rb"\ding{166}",
    "\u2767": rb"\ding{167}",
    "\u2776": rb"\ding{182}",
    "\u2777": rb"\ding{183}",
    "\u2778": rb"\ding{184}",
    "\u2779": rb"\ding{185}",
    "\u277A": rb"\ding{186}",
    "\u277B": rb"\ding{187}",
    "\u277C": rb"\ding{188}",
    "\u277D": rb"\ding{189}",
    "\u277E": rb"\ding{190}",
    "\u277F": rb"\ding{191}",
    "\u2780": rb"\ding{192}",
    "\u2781": rb"\ding{193}",
    "\u2782": rb"\ding{194}",
    "\u2783": rb"\ding{195}",
    "\u2784": rb"\ding{196}",
    "\u2785": rb"\ding{197}",
    "\u2786": rb"\ding{198}",
    "\u2787": rb"\ding{199}",
    "\u2788": rb"\ding{200}",
    "\u2789": rb"\ding{201}",
    "\u278A": rb"\ding{202}",
    "\u278B": rb"\ding{203}",
    "\u278C": rb"\ding{204}",
    "\u278D": rb"\ding{205}",
    "\u278E": rb"\ding{206}",
    "\u278F": rb"\ding{207}",
    "\u2790": rb"\ding{208}",
    "\u2791": rb"\ding{209}",
    "\u2792": rb"\ding{210}",
    "\u2793": rb"\ding{211}",
    "\u2794": rb"\ding{212}",
    "\u2798": rb"\ding{216}",
    "\u2799": rb"\ding{217}",
    "\u279A": rb"\ding{218}",
    "\u279B": rb"\ding{219}",
    "\u279C": rb"\ding{220}",
    "\u279D": rb"\ding{221}",
    "\u279E": rb"\ding{222}",
    "\u279F": rb"\ding{223}",
    "\u27A0": rb"\ding{224}",
    "\u27A1": rb"\ding{225}",
    "\u27A2": rb"\ding{226}",
    "\u27A3": rb"\ding{227}",
    "\u27A4": rb"\ding{228}",
    "\u27A5": rb"\ding{229}",
    "\u27A6": rb"\ding{230}",
    "\u27A7": rb"\ding{231}",
    "\u27A8": rb"\ding{232}",
    "\u27A9": rb"\ding{233}",
    "\u27AA": rb"\ding{234}",
    "\u27AB": rb"\ding{235}",
    "\u27AC": rb"\ding{236}",
    "\u27AD": rb"\ding{237}",
    "\u27AE": rb"\ding{238}",
    "\u27AF": rb"\ding{239}",
    "\u27B1": rb"\ding{241}",
    "\u27B2": rb"\ding{242}",
    "\u27B3": rb"\ding{243}",
    "\u27B4": rb"\ding{244}",
    "\u27B5": rb"\ding{245}",
    "\u27B6": rb"\ding{246}",
    "\u27B7": rb"\ding{247}",
    "\u27B8": rb"\ding{248}",
    "\u27B9": rb"\ding{249}",
    "\u27BA": rb"\ding{250}",
    "\u27BB": rb"\ding{251}",
    "\u27BC": rb"\ding{252}",
    "\u27BD": rb"\ding{253}",
    "\u27BE": rb"\ding{254}",
    "\u27F5": rb"\longleftarrow{}",
    "\u27F6": rb"\longrightarrow{}",
    "\u27F7": rb"\longleftrightarrow{}",
    "\u27F8": rb"\Longleftarrow{}",
    "\u27F9": rb"\Longrightarrow{}",
    "\u27FA": rb"\Longleftrightarrow{}",
    "\u27FC": rb"\longmapsto{}",
    "\u27FF": rb"\sim\joinrel\leadsto",
    "\u2905": rb"\ElsevierGlyph{E212}",
    "\u2912": rb"\UpArrowBar{}",
    "\u2913": rb"\DownArrowBar{}",
    "\u2923": rb"\ElsevierGlyph{E20C}",
    "\u2924": rb"\ElsevierGlyph{E20D}",
    "\u2925": rb"\ElsevierGlyph{E20B}",
    "\u2926": rb"\ElsevierGlyph{E20A}",
    "\u2927": rb"\ElsevierGlyph{E211}",
    "\u2928": rb"\ElsevierGlyph{E20E}",
    "\u2929": rb"\ElsevierGlyph{E20F}",
    "\u292A": rb"\ElsevierGlyph{E210}",
    "\u2933": rb"\ElsevierGlyph{E21C}",
    "\u2936": rb"\ElsevierGlyph{E21A}",
    "\u2937": rb"\ElsevierGlyph{E219}",
    "\u2940": rb"\Elolarr{}",
    "\u2941": rb"\Elorarr{}",
    "\u2942": rb"\ElzRlarr{}",
    "\u2944": rb"\ElzrLarr{}",
    "\u2947": rb"\Elzrarrx{}",
    "\u294E": rb"\LeftRightVector{}",
    "\u294F": rb"\RightUpDownVector{}",
    "\u2950": rb"\DownLeftRightVector{}",
    "\u2951": rb"\LeftUpDownVector{}",
    "\u2952": rb"\LeftVectorBar{}",
    "\u2953": rb"\RightVectorBar{}",
    "\u2954": rb"\RightUpVectorBar{}",
    "\u2955": rb"\RightDownVectorBar{}",
    "\u2956": rb"\DownLeftVectorBar{}",
    "\u2957": rb"\DownRightVectorBar{}",
    "\u2958": rb"\LeftUpVectorBar{}",
    "\u2959": rb"\LeftDownVectorBar{}",
    "\u295A": rb"\LeftTeeVector{}",
    "\u295B": rb"\RightTeeVector{}",
    "\u295C": rb"\RightUpTeeVector{}",
    "\u295D": rb"\RightDownTeeVector{}",
    "\u295E": rb"\DownLeftTeeVector{}",
    "\u295F": rb"\DownRightTeeVector{}",
    "\u2960": rb"\LeftUpTeeVector{}",
    "\u2961": rb"\LeftDownTeeVector{}",
    "\u296E": rb"\UpEquilibrium{}",
    "\u296F": rb"\ReverseUpEquilibrium{}",
    "\u2970": rb"\RoundImplies{}",
    "\u297C": rb"\ElsevierGlyph{E214}",
    "\u297D": rb"\ElsevierGlyph{E215}",
    "\u2980": rb"\Elztfnc{}",
    "\u2985": rb"\ElsevierGlyph{3018}",
    "\u2986": rb"\Elroang{}",
    "\u2993": rb"<\kern-0.58em(",
    "\u2994": rb"\ElsevierGlyph{E291}",
    "\u2999": rb"\Elzddfnc{}",
    "\u299C": rb"\Angle{}",
    "\u29A0": rb"\Elzlpargt{}",
    "\u29B5": rb"\ElsevierGlyph{E260}",
    "\u29B6": rb"\ElsevierGlyph{E61B}",
    "\u29CA": rb"\ElzLap{}",
    "\u29CB": rb"\Elzdefas{}",
    "\u29CF": rb"\LeftTriangleBar{}",
    "\u29D0": rb"\RightTriangleBar{}",
    "\u29DC": rb"\ElsevierGlyph{E372}",
    "\u29EB": rb"\blacklozenge{}",
    "\u29F4": rb"\RuleDelayed{}",
    "\u2A04": rb"\Elxuplus{}",
    "\u2A05": rb"\ElzThr{}",
    "\u2A06": rb"\Elxsqcup{}",
    "\u2A07": rb"\ElzInf{}",
    "\u2A08": rb"\ElzSup{}",
    "\u2A0D": rb"\ElzCint{}",
    "\u2A0F": rb"\clockoint{}",
    "\u2A10": rb"\ElsevierGlyph{E395}",
    "\u2A16": rb"\sqrint{}",
    "\u2A25": rb"\ElsevierGlyph{E25A}",
    "\u2A2A": rb"\ElsevierGlyph{E25B}",
    "\u2A2D": rb"\ElsevierGlyph{E25C}",
    "\u2A2E": rb"\ElsevierGlyph{E25D}",
    "\u2A2F": rb"\ElzTimes{}",
    "\u2A34": rb"\ElsevierGlyph{E25E}",
    "\u2A35": rb"\ElsevierGlyph{E25E}",
    "\u2A3C": rb"\ElsevierGlyph{E259}",
    "\u2A3F": rb"\amalg{}",
    "\u2A53": rb"\ElzAnd{}",
    "\u2A54": rb"\ElzOr{}",
    "\u2A55": rb"\ElsevierGlyph{E36E}",
    "\u2A56": rb"\ElOr{}",
    "\u2A5E": rb"\perspcorrespond{}",
    "\u2A5F": rb"\Elzminhat{}",
    "\u2A63": rb"\ElsevierGlyph{225A}",
    "\u2A6E": rb"\stackrel{*}{=}",
    "\u2A75": rb"\Equal{}",
    "\u2A7D": rb"\leqslant{}",
    "\u2A7E": rb"\geqslant{}",
    "\u2A85": rb"\lessapprox{}",
    "\u2A86": rb"\gtrapprox{}",
    "\u2A87": rb"\lneq{}",
    "\u2A88": rb"\gneq{}",
    "\u2A89": rb"\lnapprox{}",
    "\u2A8A": rb"\gnapprox{}",
    "\u2A8B": rb"\lesseqqgtr{}",
    "\u2A8C": rb"\gtreqqless{}",
    "\u2A95": rb"\eqslantless{}",
    "\u2A96": rb"\eqslantgtr{}",
    "\u2A9D": rb"\Pisymbol{ppi020}{117}",
    "\u2A9E": rb"\Pisymbol{ppi020}{105}",
    "\u2AA1": rb"\NestedLessLess{}",
    "\u2AA2": rb"\NestedGreaterGreater{}",
    "\u2AAF": rb"\preceq{}",
    "\u2AB0": rb"\succeq{}",
    "\u2AB5": rb"\precneqq{}",
    "\u2AB6": rb"\succneqq{}",
    "\u2AB7": rb"\precapprox{}",
    "\u2AB8": rb"\succapprox{}",
    "\u2AB9": rb"\precnapprox{}",
    "\u2ABA": rb"\succnapprox{}",
    "\u2AC5": rb"\subseteqq{}",
    "\u2AC6": rb"\supseteqq{}",
    "\u2ACB": rb"\subsetneqq{}",
    "\u2ACC": rb"\supsetneqq{}",
    "\u2AEB": rb"\ElsevierGlyph{E30D}",
    "\u2AF6": rb"\Elztdcol{}",
    "\u2AFD": rb"{{/}\!\!{/}}",
    "\u300A": rb"\ElsevierGlyph{300A}",
    "\u300B": rb"\ElsevierGlyph{300B}",
    "\u3018": rb"\ElsevierGlyph{3018}",
    "\u3019": rb"\ElsevierGlyph{3019}",
    "\u301A": rb"\openbracketleft{}",
    "\u301B": rb"\openbracketright{}",
    "\uFB00": rb"ff",
    "\uFB01": rb"fi",
    "\uFB02": rb"fl",
    "\uFB03": rb"ffi",
    "\uFB04": rb"ffl",
    "\uD400": rb"\mathbf{A}",
    "\uD401": rb"\mathbf{B}",
    "\uD402": rb"\mathbf{C}",
    "\uD403": rb"\mathbf{D}",
    "\uD404": rb"\mathbf{E}",
    "\uD405": rb"\mathbf{F}",
    "\uD406": rb"\mathbf{G}",
    "\uD407": rb"\mathbf{H}",
    "\uD408": rb"\mathbf{I}",
    "\uD409": rb"\mathbf{J}",
    "\uD40A": rb"\mathbf{K}",
    "\uD40B": rb"\mathbf{L}",
    "\uD40C": rb"\mathbf{M}",
    "\uD40D": rb"\mathbf{N}",
    "\uD40E": rb"\mathbf{O}",
    "\uD40F": rb"\mathbf{P}",
    "\uD410": rb"\mathbf{Q}",
    "\uD411": rb"\mathbf{R}",
    "\uD412": rb"\mathbf{S}",
    "\uD413": rb"\mathbf{T}",
    "\uD414": rb"\mathbf{U}",
    "\uD415": rb"\mathbf{V}",
    "\uD416": rb"\mathbf{W}",
    "\uD417": rb"\mathbf{X}",
    "\uD418": rb"\mathbf{Y}",
    "\uD419": rb"\mathbf{Z}",
    "\uD41A": rb"\mathbf{a}",
    "\uD41B": rb"\mathbf{b}",
    "\uD41C": rb"\mathbf{c}",
    "\uD41D": rb"\mathbf{d}",
    "\uD41E": rb"\mathbf{e}",
    "\uD41F": rb"\mathbf{f}",
    "\uD420": rb"\mathbf{g}",
    "\uD421": rb"\mathbf{h}",
    "\uD422": rb"\mathbf{i}",
    "\uD423": rb"\mathbf{j}",
    "\uD424": rb"\mathbf{k}",
    "\uD425": rb"\mathbf{l}",
    "\uD426": rb"\mathbf{m}",
    "\uD427": rb"\mathbf{n}",
    "\uD428": rb"\mathbf{o}",
    "\uD429": rb"\mathbf{p}",
    "\uD42A": rb"\mathbf{q}",
    "\uD42B": rb"\mathbf{r}",
    "\uD42C": rb"\mathbf{s}",
    "\uD42D": rb"\mathbf{t}",
    "\uD42E": rb"\mathbf{u}",
    "\uD42F": rb"\mathbf{v}",
    "\uD430": rb"\mathbf{w}",
    "\uD431": rb"\mathbf{x}",
    "\uD432": rb"\mathbf{y}",
    "\uD433": rb"\mathbf{z}",
    "\uD434": rb"\mathsl{A}",
    "\uD435": rb"\mathsl{B}",
    "\uD436": rb"\mathsl{C}",
    "\uD437": rb"\mathsl{D}",
    "\uD438": rb"\mathsl{E}",
    "\uD439": rb"\mathsl{F}",
    "\uD43A": rb"\mathsl{G}",
    "\uD43B": rb"\mathsl{H}",
    "\uD43C": rb"\mathsl{I}",
    "\uD43D": rb"\mathsl{J}",
    "\uD43E": rb"\mathsl{K}",
    "\uD43F": rb"\mathsl{L}",
    "\uD440": rb"\mathsl{M}",
    "\uD441": rb"\mathsl{N}",
    "\uD442": rb"\mathsl{O}",
    "\uD443": rb"\mathsl{P}",
    "\uD444": rb"\mathsl{Q}",
    "\uD445": rb"\mathsl{R}",
    "\uD446": rb"\mathsl{S}",
    "\uD447": rb"\mathsl{T}",
    "\uD448": rb"\mathsl{U}",
    "\uD449": rb"\mathsl{V}",
    "\uD44A": rb"\mathsl{W}",
    "\uD44B": rb"\mathsl{X}",
    "\uD44C": rb"\mathsl{Y}",
    "\uD44D": rb"\mathsl{Z}",
    "\uD44E": rb"\mathsl{a}",
    "\uD44F": rb"\mathsl{b}",
    "\uD450": rb"\mathsl{c}",
    "\uD451": rb"\mathsl{d}",
    "\uD452": rb"\mathsl{e}",
    "\uD453": rb"\mathsl{f}",
    "\uD454": rb"\mathsl{g}",
    "\uD456": rb"\mathsl{i}",
    "\uD457": rb"\mathsl{j}",
    "\uD458": rb"\mathsl{k}",
    "\uD459": rb"\mathsl{l}",
    "\uD45A": rb"\mathsl{m}",
    "\uD45B": rb"\mathsl{n}",
    "\uD45C": rb"\mathsl{o}",
    "\uD45D": rb"\mathsl{p}",
    "\uD45E": rb"\mathsl{q}",
    "\uD45F": rb"\mathsl{r}",
    "\uD460": rb"\mathsl{s}",
    "\uD461": rb"\mathsl{t}",
    "\uD462": rb"\mathsl{u}",
    "\uD463": rb"\mathsl{v}",
    "\uD464": rb"\mathsl{w}",
    "\uD465": rb"\mathsl{x}",
    "\uD466": rb"\mathsl{y}",
    "\uD467": rb"\mathsl{z}",
    "\uD468": rb"\mathbit{A}",
    "\uD469": rb"\mathbit{B}",
    "\uD46A": rb"\mathbit{C}",
    "\uD46B": rb"\mathbit{D}",
    "\uD46C": rb"\mathbit{E}",
    "\uD46D": rb"\mathbit{F}",
    "\uD46E": rb"\mathbit{G}",
    "\uD46F": rb"\mathbit{H}",
    "\uD470": rb"\mathbit{I}",
    "\uD471": rb"\mathbit{J}",
    "\uD472": rb"\mathbit{K}",
    "\uD473": rb"\mathbit{L}",
    "\uD474": rb"\mathbit{M}",
    "\uD475": rb"\mathbit{N}",
    "\uD476": rb"\mathbit{O}",
    "\uD477": rb"\mathbit{P}",
    "\uD478": rb"\mathbit{Q}",
    "\uD479": rb"\mathbit{R}",
    "\uD47A": rb"\mathbit{S}",
    "\uD47B": rb"\mathbit{T}",
    "\uD47C": rb"\mathbit{U}",
    "\uD47D": rb"\mathbit{V}",
    "\uD47E": rb"\mathbit{W}",
    "\uD47F": rb"\mathbit{X}",
    "\uD480": rb"\mathbit{Y}",
    "\uD481": rb"\mathbit{Z}",
    "\uD482": rb"\mathbit{a}",
    "\uD483": rb"\mathbit{b}",
    "\uD484": rb"\mathbit{c}",
    "\uD485": rb"\mathbit{d}",
    "\uD486": rb"\mathbit{e}",
    "\uD487": rb"\mathbit{f}",
    "\uD488": rb"\mathbit{g}",
    "\uD489": rb"\mathbit{h}",
    "\uD48A": rb"\mathbit{i}",
    "\uD48B": rb"\mathbit{j}",
    "\uD48C": rb"\mathbit{k}",
    "\uD48D": rb"\mathbit{l}",
    "\uD48E": rb"\mathbit{m}",
    "\uD48F": rb"\mathbit{n}",
    "\uD490": rb"\mathbit{o}",
    "\uD491": rb"\mathbit{p}",
    "\uD492": rb"\mathbit{q}",
    "\uD493": rb"\mathbit{r}",
    "\uD494": rb"\mathbit{s}",
    "\uD495": rb"\mathbit{t}",
    "\uD496": rb"\mathbit{u}",
    "\uD497": rb"\mathbit{v}",
    "\uD498": rb"\mathbit{w}",
    "\uD499": rb"\mathbit{x}",
    "\uD49A": rb"\mathbit{y}",
    "\uD49B": rb"\mathbit{z}",
    "\uD49C": rb"\mathscr{A}",
    "\uD49E": rb"\mathscr{C}",
    "\uD49F": rb"\mathscr{D}",
    "\uD4A2": rb"\mathscr{G}",
    "\uD4A5": rb"\mathscr{J}",
    "\uD4A6": rb"\mathscr{K}",
    "\uD4A9": rb"\mathscr{N}",
    "\uD4AA": rb"\mathscr{O}",
    "\uD4AB": rb"\mathscr{P}",
    "\uD4AC": rb"\mathscr{Q}",
    "\uD4AE": rb"\mathscr{S}",
    "\uD4AF": rb"\mathscr{T}",
    "\uD4B0": rb"\mathscr{U}",
    "\uD4B1": rb"\mathscr{V}",
    "\uD4B2": rb"\mathscr{W}",
    "\uD4B3": rb"\mathscr{X}",
    "\uD4B4": rb"\mathscr{Y}",
    "\uD4B5": rb"\mathscr{Z}",
    "\uD4B6": rb"\mathscr{a}",
    "\uD4B7": rb"\mathscr{b}",
    "\uD4B8": rb"\mathscr{c}",
    "\uD4B9": rb"\mathscr{d}",
    "\uD4BB": rb"\mathscr{f}",
    "\uD4BD": rb"\mathscr{h}",
    "\uD4BE": rb"\mathscr{i}",
    "\uD4BF": rb"\mathscr{j}",
    "\uD4C0": rb"\mathscr{k}",
    "\uD4C1": rb"\mathscr{l}",
    "\uD4C2": rb"\mathscr{m}",
    "\uD4C3": rb"\mathscr{n}",
    "\uD4C5": rb"\mathscr{p}",
    "\uD4C6": rb"\mathscr{q}",
    "\uD4C7": rb"\mathscr{r}",
    "\uD4C8": rb"\mathscr{s}",
    "\uD4C9": rb"\mathscr{t}",
    "\uD4CA": rb"\mathscr{u}",
    "\uD4CB": rb"\mathscr{v}",
    "\uD4CC": rb"\mathscr{w}",
    "\uD4CD": rb"\mathscr{x}",
    "\uD4CE": rb"\mathscr{y}",
    "\uD4CF": rb"\mathscr{z}",
    "\uD4D0": rb"\mathmit{A}",
    "\uD4D1": rb"\mathmit{B}",
    "\uD4D2": rb"\mathmit{C}",
    "\uD4D3": rb"\mathmit{D}",
    "\uD4D4": rb"\mathmit{E}",
    "\uD4D5": rb"\mathmit{F}",
    "\uD4D6": rb"\mathmit{G}",
    "\uD4D7": rb"\mathmit{H}",
    "\uD4D8": rb"\mathmit{I}",
    "\uD4D9": rb"\mathmit{J}",
    "\uD4DA": rb"\mathmit{K}",
    "\uD4DB": rb"\mathmit{L}",
    "\uD4DC": rb"\mathmit{M}",
    "\uD4DD": rb"\mathmit{N}",
    "\uD4DE": rb"\mathmit{O}",
    "\uD4DF": rb"\mathmit{P}",
    "\uD4E0": rb"\mathmit{Q}",
    "\uD4E1": rb"\mathmit{R}",
    "\uD4E2": rb"\mathmit{S}",
    "\uD4E3": rb"\mathmit{T}",
    "\uD4E4": rb"\mathmit{U}",
    "\uD4E5": rb"\mathmit{V}",
    "\uD4E6": rb"\mathmit{W}",
    "\uD4E7": rb"\mathmit{X}",
    "\uD4E8": rb"\mathmit{Y}",
    "\uD4E9": rb"\mathmit{Z}",
    "\uD4EA": rb"\mathmit{a}",
    "\uD4EB": rb"\mathmit{b}",
    "\uD4EC": rb"\mathmit{c}",
    "\uD4ED": rb"\mathmit{d}",
    "\uD4EE": rb"\mathmit{e}",
    "\uD4EF": rb"\mathmit{f}",
    "\uD4F0": rb"\mathmit{g}",
    "\uD4F1": rb"\mathmit{h}",
    "\uD4F2": rb"\mathmit{i}",
    "\uD4F3": rb"\mathmit{j}",
    "\uD4F4": rb"\mathmit{k}",
    "\uD4F5": rb"\mathmit{l}",
    "\uD4F6": rb"\mathmit{m}",
    "\uD4F7": rb"\mathmit{n}",
    "\uD4F8": rb"\mathmit{o}",
    "\uD4F9": rb"\mathmit{p}",
    "\uD4FA": rb"\mathmit{q}",
    "\uD4FB": rb"\mathmit{r}",
    "\uD4FC": rb"\mathmit{s}",
    "\uD4FD": rb"\mathmit{t}",
    "\uD4FE": rb"\mathmit{u}",
    "\uD4FF": rb"\mathmit{v}",
    "\uD500": rb"\mathmit{w}",
    "\uD501": rb"\mathmit{x}",
    "\uD502": rb"\mathmit{y}",
    "\uD503": rb"\mathmit{z}",
    "\uD504": rb"\mathfrak{A}",
    "\uD505": rb"\mathfrak{B}",
    "\uD507": rb"\mathfrak{D}",
    "\uD508": rb"\mathfrak{E}",
    "\uD509": rb"\mathfrak{F}",
    "\uD50A": rb"\mathfrak{G}",
    "\uD50D": rb"\mathfrak{J}",
    "\uD50E": rb"\mathfrak{K}",
    "\uD50F": rb"\mathfrak{L}",
    "\uD510": rb"\mathfrak{M}",
    "\uD511": rb"\mathfrak{N}",
    "\uD512": rb"\mathfrak{O}",
    "\uD513": rb"\mathfrak{P}",
    "\uD514": rb"\mathfrak{Q}",
    "\uD516": rb"\mathfrak{S}",
    "\uD517": rb"\mathfrak{T}",
    "\uD518": rb"\mathfrak{U}",
    "\uD519": rb"\mathfrak{V}",
    "\uD51A": rb"\mathfrak{W}",
    "\uD51B": rb"\mathfrak{X}",
    "\uD51C": rb"\mathfrak{Y}",
    "\uD51E": rb"\mathfrak{a}",
    "\uD51F": rb"\mathfrak{b}",
    "\uD520": rb"\mathfrak{c}",
    "\uD521": rb"\mathfrak{d}",
    "\uD522": rb"\mathfrak{e}",
    "\uD523": rb"\mathfrak{f}",
    "\uD524": rb"\mathfrak{g}",
    "\uD525": rb"\mathfrak{h}",
    "\uD526": rb"\mathfrak{i}",
    "\uD527": rb"\mathfrak{j}",
    "\uD528": rb"\mathfrak{k}",
    "\uD529": rb"\mathfrak{l}",
    "\uD52A": rb"\mathfrak{m}",
    "\uD52B": rb"\mathfrak{n}",
    "\uD52C": rb"\mathfrak{o}",
    "\uD52D": rb"\mathfrak{p}",
    "\uD52E": rb"\mathfrak{q}",
    "\uD52F": rb"\mathfrak{r}",
    "\uD530": rb"\mathfrak{s}",
    "\uD531": rb"\mathfrak{t}",
    "\uD532": rb"\mathfrak{u}",
    "\uD533": rb"\mathfrak{v}",
    "\uD534": rb"\mathfrak{w}",
    "\uD535": rb"\mathfrak{x}",
    "\uD536": rb"\mathfrak{y}",
    "\uD537": rb"\mathfrak{z}",
    "\uD538": rb"\mathbb{A}",
    "\uD539": rb"\mathbb{B}",
    "\uD53B": rb"\mathbb{D}",
    "\uD53C": rb"\mathbb{E}",
    "\uD53D": rb"\mathbb{F}",
    "\uD53E": rb"\mathbb{G}",
    "\uD540": rb"\mathbb{I}",
    "\uD541": rb"\mathbb{J}",
    "\uD542": rb"\mathbb{K}",
    "\uD543": rb"\mathbb{L}",
    "\uD544": rb"\mathbb{M}",
    "\uD546": rb"\mathbb{O}",
    "\uD54A": rb"\mathbb{S}",
    "\uD54B": rb"\mathbb{T}",
    "\uD54C": rb"\mathbb{U}",
    "\uD54D": rb"\mathbb{V}",
    "\uD54E": rb"\mathbb{W}",
    "\uD54F": rb"\mathbb{X}",
    "\uD550": rb"\mathbb{Y}",
    "\uD552": rb"\mathbb{a}",
    "\uD553": rb"\mathbb{b}",
    "\uD554": rb"\mathbb{c}",
    "\uD555": rb"\mathbb{d}",
    "\uD556": rb"\mathbb{e}",
    "\uD557": rb"\mathbb{f}",
    "\uD558": rb"\mathbb{g}",
    "\uD559": rb"\mathbb{h}",
    "\uD55A": rb"\mathbb{i}",
    "\uD55B": rb"\mathbb{j}",
    "\uD55C": rb"\mathbb{k}",
    "\uD55D": rb"\mathbb{l}",
    "\uD55E": rb"\mathbb{m}",
    "\uD55F": rb"\mathbb{n}",
    "\uD560": rb"\mathbb{o}",
    "\uD561": rb"\mathbb{p}",
    "\uD562": rb"\mathbb{q}",
    "\uD563": rb"\mathbb{r}",
    "\uD564": rb"\mathbb{s}",
    "\uD565": rb"\mathbb{t}",
    "\uD566": rb"\mathbb{u}",
    "\uD567": rb"\mathbb{v}",
    "\uD568": rb"\mathbb{w}",
    "\uD569": rb"\mathbb{x}",
    "\uD56A": rb"\mathbb{y}",
    "\uD56B": rb"\mathbb{z}",
    "\uD56C": rb"\mathslbb{A}",
    "\uD56D": rb"\mathslbb{B}",
    "\uD56E": rb"\mathslbb{C}",
    "\uD56F": rb"\mathslbb{D}",
    "\uD570": rb"\mathslbb{E}",
    "\uD571": rb"\mathslbb{F}",
    "\uD572": rb"\mathslbb{G}",
    "\uD573": rb"\mathslbb{H}",
    "\uD574": rb"\mathslbb{I}",
    "\uD575": rb"\mathslbb{J}",
    "\uD576": rb"\mathslbb{K}",
    "\uD577": rb"\mathslbb{L}",
    "\uD578": rb"\mathslbb{M}",
    "\uD579": rb"\mathslbb{N}",
    "\uD57A": rb"\mathslbb{O}",
    "\uD57B": rb"\mathslbb{P}",
    "\uD57C": rb"\mathslbb{Q}",
    "\uD57D": rb"\mathslbb{R}",
    "\uD57E": rb"\mathslbb{S}",
    "\uD57F": rb"\mathslbb{T}",
    "\uD580": rb"\mathslbb{U}",
    "\uD581": rb"\mathslbb{V}",
    "\uD582": rb"\mathslbb{W}",
    "\uD583": rb"\mathslbb{X}",
    "\uD584": rb"\mathslbb{Y}",
    "\uD585": rb"\mathslbb{Z}",
    "\uD586": rb"\mathslbb{a}",
    "\uD587": rb"\mathslbb{b}",
    "\uD588": rb"\mathslbb{c}",
    "\uD589": rb"\mathslbb{d}",
    "\uD58A": rb"\mathslbb{e}",
    "\uD58B": rb"\mathslbb{f}",
    "\uD58C": rb"\mathslbb{g}",
    "\uD58D": rb"\mathslbb{h}",
    "\uD58E": rb"\mathslbb{i}",
    "\uD58F": rb"\mathslbb{j}",
    "\uD590": rb"\mathslbb{k}",
    "\uD591": rb"\mathslbb{l}",
    "\uD592": rb"\mathslbb{m}",
    "\uD593": rb"\mathslbb{n}",
    "\uD594": rb"\mathslbb{o}",
    "\uD595": rb"\mathslbb{p}",
    "\uD596": rb"\mathslbb{q}",
    "\uD597": rb"\mathslbb{r}",
    "\uD598": rb"\mathslbb{s}",
    "\uD599": rb"\mathslbb{t}",
    "\uD59A": rb"\mathslbb{u}",
    "\uD59B": rb"\mathslbb{v}",
    "\uD59C": rb"\mathslbb{w}",
    "\uD59D": rb"\mathslbb{x}",
    "\uD59E": rb"\mathslbb{y}",
    "\uD59F": rb"\mathslbb{z}",
    "\uD5A0": rb"\mathsf{A}",
    "\uD5A1": rb"\mathsf{B}",
    "\uD5A2": rb"\mathsf{C}",
    "\uD5A3": rb"\mathsf{D}",
    "\uD5A4": rb"\mathsf{E}",
    "\uD5A5": rb"\mathsf{F}",
    "\uD5A6": rb"\mathsf{G}",
    "\uD5A7": rb"\mathsf{H}",
    "\uD5A8": rb"\mathsf{I}",
    "\uD5A9": rb"\mathsf{J}",
    "\uD5AA": rb"\mathsf{K}",
    "\uD5AB": rb"\mathsf{L}",
    "\uD5AC": rb"\mathsf{M}",
    "\uD5AD": rb"\mathsf{N}",
    "\uD5AE": rb"\mathsf{O}",
    "\uD5AF": rb"\mathsf{P}",
    "\uD5B0": rb"\mathsf{Q}",
    "\uD5B1": rb"\mathsf{R}",
    "\uD5B2": rb"\mathsf{S}",
    "\uD5B3": rb"\mathsf{T}",
    "\uD5B4": rb"\mathsf{U}",
    "\uD5B5": rb"\mathsf{V}",
    "\uD5B6": rb"\mathsf{W}",
    "\uD5B7": rb"\mathsf{X}",
    "\uD5B8": rb"\mathsf{Y}",
    "\uD5B9": rb"\mathsf{Z}",
    "\uD5BA": rb"\mathsf{a}",
    "\uD5BB": rb"\mathsf{b}",
    "\uD5BC": rb"\mathsf{c}",
    "\uD5BD": rb"\mathsf{d}",
    "\uD5BE": rb"\mathsf{e}",
    "\uD5BF": rb"\mathsf{f}",
    "\uD5C0": rb"\mathsf{g}",
    "\uD5C1": rb"\mathsf{h}",
    "\uD5C2": rb"\mathsf{i}",
    "\uD5C3": rb"\mathsf{j}",
    "\uD5C4": rb"\mathsf{k}",
    "\uD5C5": rb"\mathsf{l}",
    "\uD5C6": rb"\mathsf{m}",
    "\uD5C7": rb"\mathsf{n}",
    "\uD5C8": rb"\mathsf{o}",
    "\uD5C9": rb"\mathsf{p}",
    "\uD5CA": rb"\mathsf{q}",
    "\uD5CB": rb"\mathsf{r}",
    "\uD5CC": rb"\mathsf{s}",
    "\uD5CD": rb"\mathsf{t}",
    "\uD5CE": rb"\mathsf{u}",
    "\uD5CF": rb"\mathsf{v}",
    "\uD5D0": rb"\mathsf{w}",
    "\uD5D1": rb"\mathsf{x}",
    "\uD5D2": rb"\mathsf{y}",
    "\uD5D3": rb"\mathsf{z}",
    "\uD5D4": rb"\mathsfbf{A}",
    "\uD5D5": rb"\mathsfbf{B}",
    "\uD5D6": rb"\mathsfbf{C}",
    "\uD5D7": rb"\mathsfbf{D}",
    "\uD5D8": rb"\mathsfbf{E}",
    "\uD5D9": rb"\mathsfbf{F}",
    "\uD5DA": rb"\mathsfbf{G}",
    "\uD5DB": rb"\mathsfbf{H}",
    "\uD5DC": rb"\mathsfbf{I}",
    "\uD5DD": rb"\mathsfbf{J}",
    "\uD5DE": rb"\mathsfbf{K}",
    "\uD5DF": rb"\mathsfbf{L}",
    "\uD5E0": rb"\mathsfbf{M}",
    "\uD5E1": rb"\mathsfbf{N}",
    "\uD5E2": rb"\mathsfbf{O}",
    "\uD5E3": rb"\mathsfbf{P}",
    "\uD5E4": rb"\mathsfbf{Q}",
    "\uD5E5": rb"\mathsfbf{R}",
    "\uD5E6": rb"\mathsfbf{S}",
    "\uD5E7": rb"\mathsfbf{T}",
    "\uD5E8": rb"\mathsfbf{U}",
    "\uD5E9": rb"\mathsfbf{V}",
    "\uD5EA": rb"\mathsfbf{W}",
    "\uD5EB": rb"\mathsfbf{X}",
    "\uD5EC": rb"\mathsfbf{Y}",
    "\uD5ED": rb"\mathsfbf{Z}",
    "\uD5EE": rb"\mathsfbf{a}",
    "\uD5EF": rb"\mathsfbf{b}",
    "\uD5F0": rb"\mathsfbf{c}",
    "\uD5F1": rb"\mathsfbf{d}",
    "\uD5F2": rb"\mathsfbf{e}",
    "\uD5F3": rb"\mathsfbf{f}",
    "\uD5F4": rb"\mathsfbf{g}",
    "\uD5F5": rb"\mathsfbf{h}",
    "\uD5F6": rb"\mathsfbf{i}",
    "\uD5F7": rb"\mathsfbf{j}",
    "\uD5F8": rb"\mathsfbf{k}",
    "\uD5F9": rb"\mathsfbf{l}",
    "\uD5FA": rb"\mathsfbf{m}",
    "\uD5FB": rb"\mathsfbf{n}",
    "\uD5FC": rb"\mathsfbf{o}",
    "\uD5FD": rb"\mathsfbf{p}",
    "\uD5FE": rb"\mathsfbf{q}",
    "\uD5FF": rb"\mathsfbf{r}",
    "\uD600": rb"\mathsfbf{s}",
    "\uD601": rb"\mathsfbf{t}",
    "\uD602": rb"\mathsfbf{u}",
    "\uD603": rb"\mathsfbf{v}",
    "\uD604": rb"\mathsfbf{w}",
    "\uD605": rb"\mathsfbf{x}",
    "\uD606": rb"\mathsfbf{y}",
    "\uD607": rb"\mathsfbf{z}",
    "\uD608": rb"\mathsfsl{A}",
    "\uD609": rb"\mathsfsl{B}",
    "\uD60A": rb"\mathsfsl{C}",
    "\uD60B": rb"\mathsfsl{D}",
    "\uD60C": rb"\mathsfsl{E}",
    "\uD60D": rb"\mathsfsl{F}",
    "\uD60E": rb"\mathsfsl{G}",
    "\uD60F": rb"\mathsfsl{H}",
    "\uD610": rb"\mathsfsl{I}",
    "\uD611": rb"\mathsfsl{J}",
    "\uD612": rb"\mathsfsl{K}",
    "\uD613": rb"\mathsfsl{L}",
    "\uD614": rb"\mathsfsl{M}",
    "\uD615": rb"\mathsfsl{N}",
    "\uD616": rb"\mathsfsl{O}",
    "\uD617": rb"\mathsfsl{P}",
    "\uD618": rb"\mathsfsl{Q}",
    "\uD619": rb"\mathsfsl{R}",
    "\uD61A": rb"\mathsfsl{S}",
    "\uD61B": rb"\mathsfsl{T}",
    "\uD61C": rb"\mathsfsl{U}",
    "\uD61D": rb"\mathsfsl{V}",
    "\uD61E": rb"\mathsfsl{W}",
    "\uD61F": rb"\mathsfsl{X}",
    "\uD620": rb"\mathsfsl{Y}",
    "\uD621": rb"\mathsfsl{Z}",
    "\uD622": rb"\mathsfsl{a}",
    "\uD623": rb"\mathsfsl{b}",
    "\uD624": rb"\mathsfsl{c}",
    "\uD625": rb"\mathsfsl{d}",
    "\uD626": rb"\mathsfsl{e}",
    "\uD627": rb"\mathsfsl{f}",
    "\uD628": rb"\mathsfsl{g}",
    "\uD629": rb"\mathsfsl{h}",
    "\uD62A": rb"\mathsfsl{i}",
    "\uD62B": rb"\mathsfsl{j}",
    "\uD62C": rb"\mathsfsl{k}",
    "\uD62D": rb"\mathsfsl{l}",
    "\uD62E": rb"\mathsfsl{m}",
    "\uD62F": rb"\mathsfsl{n}",
    "\uD630": rb"\mathsfsl{o}",
    "\uD631": rb"\mathsfsl{p}",
    "\uD632": rb"\mathsfsl{q}",
    "\uD633": rb"\mathsfsl{r}",
    "\uD634": rb"\mathsfsl{s}",
    "\uD635": rb"\mathsfsl{t}",
    "\uD636": rb"\mathsfsl{u}",
    "\uD637": rb"\mathsfsl{v}",
    "\uD638": rb"\mathsfsl{w}",
    "\uD639": rb"\mathsfsl{x}",
    "\uD63A": rb"\mathsfsl{y}",
    "\uD63B": rb"\mathsfsl{z}",
    "\uD63C": rb"\mathsfbfsl{A}",
    "\uD63D": rb"\mathsfbfsl{B}",
    "\uD63E": rb"\mathsfbfsl{C}",
    "\uD63F": rb"\mathsfbfsl{D}",
    "\uD640": rb"\mathsfbfsl{E}",
    "\uD641": rb"\mathsfbfsl{F}",
    "\uD642": rb"\mathsfbfsl{G}",
    "\uD643": rb"\mathsfbfsl{H}",
    "\uD644": rb"\mathsfbfsl{I}",
    "\uD645": rb"\mathsfbfsl{J}",
    "\uD646": rb"\mathsfbfsl{K}",
    "\uD647": rb"\mathsfbfsl{L}",
    "\uD648": rb"\mathsfbfsl{M}",
    "\uD649": rb"\mathsfbfsl{N}",
    "\uD64A": rb"\mathsfbfsl{O}",
    "\uD64B": rb"\mathsfbfsl{P}",
    "\uD64C": rb"\mathsfbfsl{Q}",
    "\uD64D": rb"\mathsfbfsl{R}",
    "\uD64E": rb"\mathsfbfsl{S}",
    "\uD64F": rb"\mathsfbfsl{T}",
    "\uD650": rb"\mathsfbfsl{U}",
    "\uD651": rb"\mathsfbfsl{V}",
    "\uD652": rb"\mathsfbfsl{W}",
    "\uD653": rb"\mathsfbfsl{X}",
    "\uD654": rb"\mathsfbfsl{Y}",
    "\uD655": rb"\mathsfbfsl{Z}",
    "\uD656": rb"\mathsfbfsl{a}",
    "\uD657": rb"\mathsfbfsl{b}",
    "\uD658": rb"\mathsfbfsl{c}",
    "\uD659": rb"\mathsfbfsl{d}",
    "\uD65A": rb"\mathsfbfsl{e}",
    "\uD65B": rb"\mathsfbfsl{f}",
    "\uD65C": rb"\mathsfbfsl{g}",
    "\uD65D": rb"\mathsfbfsl{h}",
    "\uD65E": rb"\mathsfbfsl{i}",
    "\uD65F": rb"\mathsfbfsl{j}",
    "\uD660": rb"\mathsfbfsl{k}",
    "\uD661": rb"\mathsfbfsl{l}",
    "\uD662": rb"\mathsfbfsl{m}",
    "\uD663": rb"\mathsfbfsl{n}",
    "\uD664": rb"\mathsfbfsl{o}",
    "\uD665": rb"\mathsfbfsl{p}",
    "\uD666": rb"\mathsfbfsl{q}",
    "\uD667": rb"\mathsfbfsl{r}",
    "\uD668": rb"\mathsfbfsl{s}",
    "\uD669": rb"\mathsfbfsl{t}",
    "\uD66A": rb"\mathsfbfsl{u}",
    "\uD66B": rb"\mathsfbfsl{v}",
    "\uD66C": rb"\mathsfbfsl{w}",
    "\uD66D": rb"\mathsfbfsl{x}",
    "\uD66E": rb"\mathsfbfsl{y}",
    "\uD66F": rb"\mathsfbfsl{z}",
    "\uD670": rb"\mathtt{A}",
    "\uD671": rb"\mathtt{B}",
    "\uD672": rb"\mathtt{C}",
    "\uD673": rb"\mathtt{D}",
    "\uD674": rb"\mathtt{E}",
    "\uD675": rb"\mathtt{F}",
    "\uD676": rb"\mathtt{G}",
    "\uD677": rb"\mathtt{H}",
    "\uD678": rb"\mathtt{I}",
    "\uD679": rb"\mathtt{J}",
    "\uD67A": rb"\mathtt{K}",
    "\uD67B": rb"\mathtt{L}",
    "\uD67C": rb"\mathtt{M}",
    "\uD67D": rb"\mathtt{N}",
    "\uD67E": rb"\mathtt{O}",
    "\uD67F": rb"\mathtt{P}",
    "\uD680": rb"\mathtt{Q}",
    "\uD681": rb"\mathtt{R}",
    "\uD682": rb"\mathtt{S}",
    "\uD683": rb"\mathtt{T}",
    "\uD684": rb"\mathtt{U}",
    "\uD685": rb"\mathtt{V}",
    "\uD686": rb"\mathtt{W}",
    "\uD687": rb"\mathtt{X}",
    "\uD688": rb"\mathtt{Y}",
    "\uD689": rb"\mathtt{Z}",
    "\uD68A": rb"\mathtt{a}",
    "\uD68B": rb"\mathtt{b}",
    "\uD68C": rb"\mathtt{c}",
    "\uD68D": rb"\mathtt{d}",
    "\uD68E": rb"\mathtt{e}",
    "\uD68F": rb"\mathtt{f}",
    "\uD690": rb"\mathtt{g}",
    "\uD691": rb"\mathtt{h}",
    "\uD692": rb"\mathtt{i}",
    "\uD693": rb"\mathtt{j}",
    "\uD694": rb"\mathtt{k}",
    "\uD695": rb"\mathtt{l}",
    "\uD696": rb"\mathtt{m}",
    "\uD697": rb"\mathtt{n}",
    "\uD698": rb"\mathtt{o}",
    "\uD699": rb"\mathtt{p}",
    "\uD69A": rb"\mathtt{q}",
    "\uD69B": rb"\mathtt{r}",
    "\uD69C": rb"\mathtt{s}",
    "\uD69D": rb"\mathtt{t}",
    "\uD69E": rb"\mathtt{u}",
    "\uD69F": rb"\mathtt{v}",
    "\uD6A0": rb"\mathtt{w}",
    "\uD6A1": rb"\mathtt{x}",
    "\uD6A2": rb"\mathtt{y}",
    "\uD6A3": rb"\mathtt{z}",
    "\uD6A8": rb"\mathbf{\Alpha}",
    "\uD6A9": rb"\mathbf{\Beta}",
    "\uD6AA": rb"\mathbf{\Gamma}",
    "\uD6AB": rb"\mathbf{\Delta}",
    "\uD6AC": rb"\mathbf{\Epsilon}",
    "\uD6AD": rb"\mathbf{\Zeta}",
    "\uD6AE": rb"\mathbf{\Eta}",
    "\uD6AF": rb"\mathbf{\Theta}",
    "\uD6B0": rb"\mathbf{\Iota}",
    "\uD6B1": rb"\mathbf{\Kappa}",
    "\uD6B2": rb"\mathbf{\Lambda}",
    "\uD6B5": rb"\mathbf{\Xi}",
    "\uD6B7": rb"\mathbf{\Pi}",
    "\uD6B8": rb"\mathbf{\Rho}",
    "\uD6B9": rb"\mathbf{\vartheta}",
    "\uD6BA": rb"\mathbf{\Sigma}",
    "\uD6BB": rb"\mathbf{\Tau}",
    "\uD6BC": rb"\mathbf{\Upsilon}",
    "\uD6BD": rb"\mathbf{\Phi}",
    "\uD6BE": rb"\mathbf{\Chi}",
    "\uD6BF": rb"\mathbf{\Psi}",
    "\uD6C0": rb"\mathbf{\Omega}",
    "\uD6C1": rb"\mathbf{\nabla}",
    "\uD6C2": rb"\mathbf{\Alpha}",
    "\uD6C3": rb"\mathbf{\Beta}",
    "\uD6C4": rb"\mathbf{\Gamma}",
    "\uD6C5": rb"\mathbf{\Delta}",
    "\uD6C6": rb"\mathbf{\Epsilon}",
    "\uD6C7": rb"\mathbf{\Zeta}",
    "\uD6C8": rb"\mathbf{\Eta}",
    "\uD6C9": rb"\mathbf{\theta}",
    "\uD6CA": rb"\mathbf{\Iota}",
    "\uD6CB": rb"\mathbf{\Kappa}",
    "\uD6CC": rb"\mathbf{\Lambda}",
    "\uD6CF": rb"\mathbf{\Xi}",
    "\uD6D1": rb"\mathbf{\Pi}",
    "\uD6D2": rb"\mathbf{\Rho}",
    "\uD6D3": rb"\mathbf{\varsigma}",
    "\uD6D4": rb"\mathbf{\Sigma}",
    "\uD6D5": rb"\mathbf{\Tau}",
    "\uD6D6": rb"\mathbf{\Upsilon}",
    "\uD6D7": rb"\mathbf{\Phi}",
    "\uD6D8": rb"\mathbf{\Chi}",
    "\uD6D9": rb"\mathbf{\Psi}",
    "\uD6DA": rb"\mathbf{\Omega}",
    "\uD6DB": rb"\partial{}",
    "\uD6DC": rb"\in",
    "\uD6DD": rb"\mathbf{\vartheta}",
    "\uD6DE": rb"\mathbf{\varkappa}",
    "\uD6DF": rb"\mathbf{\phi}",
    "\uD6E0": rb"\mathbf{\varrho}",
    "\uD6E1": rb"\mathbf{\varpi}",
    "\uD6E2": rb"\mathsl{\Alpha}",
    "\uD6E3": rb"\mathsl{\Beta}",
    "\uD6E4": rb"\mathsl{\Gamma}",
    "\uD6E5": rb"\mathsl{\Delta}",
    "\uD6E6": rb"\mathsl{\Epsilon}",
    "\uD6E7": rb"\mathsl{\Zeta}",
    "\uD6E8": rb"\mathsl{\Eta}",
    "\uD6E9": rb"\mathsl{\Theta}",
    "\uD6EA": rb"\mathsl{\Iota}",
    "\uD6EB": rb"\mathsl{\Kappa}",
    "\uD6EC": rb"\mathsl{\Lambda}",
    "\uD6EF": rb"\mathsl{\Xi}",
    "\uD6F1": rb"\mathsl{\Pi}",
    "\uD6F2": rb"\mathsl{\Rho}",
    "\uD6F3": rb"\mathsl{\vartheta}",
    "\uD6F4": rb"\mathsl{\Sigma}",
    "\uD6F5": rb"\mathsl{\Tau}",
    "\uD6F6": rb"\mathsl{\Upsilon}",
    "\uD6F7": rb"\mathsl{\Phi}",
    "\uD6F8": rb"\mathsl{\Chi}",
    "\uD6F9": rb"\mathsl{\Psi}",
    "\uD6FA": rb"\mathsl{\Omega}",
    "\uD6FB": rb"\mathsl{\nabla}",
    "\uD6FC": rb"\mathsl{\Alpha}",
    "\uD6FD": rb"\mathsl{\Beta}",
    "\uD6FE": rb"\mathsl{\Gamma}",
    "\uD6FF": rb"\mathsl{\Delta}",
    "\uD700": rb"\mathsl{\Epsilon}",
    "\uD701": rb"\mathsl{\Zeta}",
    "\uD702": rb"\mathsl{\Eta}",
    "\uD703": rb"\mathsl{\Theta}",
    "\uD704": rb"\mathsl{\Iota}",
    "\uD705": rb"\mathsl{\Kappa}",
    "\uD706": rb"\mathsl{\Lambda}",
    "\uD709": rb"\mathsl{\Xi}",
    "\uD70B": rb"\mathsl{\Pi}",
    "\uD70C": rb"\mathsl{\Rho}",
    "\uD70D": rb"\mathsl{\varsigma}",
    "\uD70E": rb"\mathsl{\Sigma}",
    "\uD70F": rb"\mathsl{\Tau}",
    "\uD710": rb"\mathsl{\Upsilon}",
    "\uD711": rb"\mathsl{\Phi}",
    "\uD712": rb"\mathsl{\Chi}",
    "\uD713": rb"\mathsl{\Psi}",
    "\uD714": rb"\mathsl{\Omega}",
    "\uD715": rb"\partial{}",
    "\uD716": rb"\in",
    "\uD717": rb"\mathsl{\vartheta}",
    "\uD718": rb"\mathsl{\varkappa}",
    "\uD719": rb"\mathsl{\phi}",
    "\uD71A": rb"\mathsl{\varrho}",
    "\uD71B": rb"\mathsl{\varpi}",
    "\uD71C": rb"\mathbit{\Alpha}",
    "\uD71D": rb"\mathbit{\Beta}",
    "\uD71E": rb"\mathbit{\Gamma}",
    "\uD71F": rb"\mathbit{\Delta}",
    "\uD720": rb"\mathbit{\Epsilon}",
    "\uD721": rb"\mathbit{\Zeta}",
    "\uD722": rb"\mathbit{\Eta}",
    "\uD723": rb"\mathbit{\Theta}",
    "\uD724": rb"\mathbit{\Iota}",
    "\uD725": rb"\mathbit{\Kappa}",
    "\uD726": rb"\mathbit{\Lambda}",
    "\uD729": rb"\mathbit{\Xi}",
    "\uD72B": rb"\mathbit{\Pi}",
    "\uD72C": rb"\mathbit{\Rho}",
    "\uD72D": rb"\mathbit{O}",
    "\uD72E": rb"\mathbit{\Sigma}",
    "\uD72F": rb"\mathbit{\Tau}",
    "\uD730": rb"\mathbit{\Upsilon}",
    "\uD731": rb"\mathbit{\Phi}",
    "\uD732": rb"\mathbit{\Chi}",
    "\uD733": rb"\mathbit{\Psi}",
    "\uD734": rb"\mathbit{\Omega}",
    "\uD735": rb"\mathbit{\nabla}",
    "\uD736": rb"\mathbit{\Alpha}",
    "\uD737": rb"\mathbit{\Beta}",
    "\uD738": rb"\mathbit{\Gamma}",
    "\uD739": rb"\mathbit{\Delta}",
    "\uD73A": rb"\mathbit{\Epsilon}",
    "\uD73B": rb"\mathbit{\Zeta}",
    "\uD73C": rb"\mathbit{\Eta}",
    "\uD73D": rb"\mathbit{\Theta}",
    "\uD73E": rb"\mathbit{\Iota}",
    "\uD73F": rb"\mathbit{\Kappa}",
    "\uD740": rb"\mathbit{\Lambda}",
    "\uD743": rb"\mathbit{\Xi}",
    "\uD745": rb"\mathbit{\Pi}",
    "\uD746": rb"\mathbit{\Rho}",
    "\uD747": rb"\mathbit{\varsigma}",
    "\uD748": rb"\mathbit{\Sigma}",
    "\uD749": rb"\mathbit{\Tau}",
    "\uD74A": rb"\mathbit{\Upsilon}",
    "\uD74B": rb"\mathbit{\Phi}",
    "\uD74C": rb"\mathbit{\Chi}",
    "\uD74D": rb"\mathbit{\Psi}",
    "\uD74E": rb"\mathbit{\Omega}",
    "\uD74F": rb"\partial{}",
    "\uD750": rb"\in",
    "\uD751": rb"\mathbit{\vartheta}",
    "\uD752": rb"\mathbit{\varkappa}",
    "\uD753": rb"\mathbit{\phi}",
    "\uD754": rb"\mathbit{\varrho}",
    "\uD755": rb"\mathbit{\varpi}",
    "\uD756": rb"\mathsfbf{\Alpha}",
    "\uD757": rb"\mathsfbf{\Beta}",
    "\uD758": rb"\mathsfbf{\Gamma}",
    "\uD759": rb"\mathsfbf{\Delta}",
    "\uD75A": rb"\mathsfbf{\Epsilon}",
    "\uD75B": rb"\mathsfbf{\Zeta}",
    "\uD75C": rb"\mathsfbf{\Eta}",
    "\uD75D": rb"\mathsfbf{\Theta}",
    "\uD75E": rb"\mathsfbf{\Iota}",
    "\uD75F": rb"\mathsfbf{\Kappa}",
    "\uD760": rb"\mathsfbf{\Lambda}",
    "\uD763": rb"\mathsfbf{\Xi}",
    "\uD765": rb"\mathsfbf{\Pi}",
    "\uD766": rb"\mathsfbf{\Rho}",
    "\uD767": rb"\mathsfbf{\vartheta}",
    "\uD768": rb"\mathsfbf{\Sigma}",
    "\uD769": rb"\mathsfbf{\Tau}",
    "\uD76A": rb"\mathsfbf{\Upsilon}",
    "\uD76B": rb"\mathsfbf{\Phi}",
    "\uD76C": rb"\mathsfbf{\Chi}",
    "\uD76D": rb"\mathsfbf{\Psi}",
    "\uD76E": rb"\mathsfbf{\Omega}",
    "\uD76F": rb"\mathsfbf{\nabla}",
    "\uD770": rb"\mathsfbf{\Alpha}",
    "\uD771": rb"\mathsfbf{\Beta}",
    "\uD772": rb"\mathsfbf{\Gamma}",
    "\uD773": rb"\mathsfbf{\Delta}",
    "\uD774": rb"\mathsfbf{\Epsilon}",
    "\uD775": rb"\mathsfbf{\Zeta}",
    "\uD776": rb"\mathsfbf{\Eta}",
    "\uD777": rb"\mathsfbf{\Theta}",
    "\uD778": rb"\mathsfbf{\Iota}",
    "\uD779": rb"\mathsfbf{\Kappa}",
    "\uD77A": rb"\mathsfbf{\Lambda}",
    "\uD77D": rb"\mathsfbf{\Xi}",
    "\uD77F": rb"\mathsfbf{\Pi}",
    "\uD780": rb"\mathsfbf{\Rho}",
    "\uD781": rb"\mathsfbf{\varsigma}",
    "\uD782": rb"\mathsfbf{\Sigma}",
    "\uD783": rb"\mathsfbf{\Tau}",
    "\uD784": rb"\mathsfbf{\Upsilon}",
    "\uD785": rb"\mathsfbf{\Phi}",
    "\uD786": rb"\mathsfbf{\Chi}",
    "\uD787": rb"\mathsfbf{\Psi}",
    "\uD788": rb"\mathsfbf{\Omega}",
    "\uD789": rb"\partial{}",
    "\uD78A": rb"\in",
    "\uD78B": rb"\mathsfbf{\vartheta}",
    "\uD78C": rb"\mathsfbf{\varkappa}",
    "\uD78D": rb"\mathsfbf{\phi}",
    "\uD78E": rb"\mathsfbf{\varrho}",
    "\uD78F": rb"\mathsfbf{\varpi}",
    "\uD790": rb"\mathsfbfsl{\Alpha}",
    "\uD791": rb"\mathsfbfsl{\Beta}",
    "\uD792": rb"\mathsfbfsl{\Gamma}",
    "\uD793": rb"\mathsfbfsl{\Delta}",
    "\uD794": rb"\mathsfbfsl{\Epsilon}",
    "\uD795": rb"\mathsfbfsl{\Zeta}",
    "\uD796": rb"\mathsfbfsl{\Eta}",
    "\uD797": rb"\mathsfbfsl{\vartheta}",
    "\uD798": rb"\mathsfbfsl{\Iota}",
    "\uD799": rb"\mathsfbfsl{\Kappa}",
    "\uD79A": rb"\mathsfbfsl{\Lambda}",
    "\uD79D": rb"\mathsfbfsl{\Xi}",
    "\uD79F": rb"\mathsfbfsl{\Pi}",
    "\uD7A0": rb"\mathsfbfsl{\Rho}",
    "\uD7A1": rb"\mathsfbfsl{\vartheta}",
    "\uD7A2": rb"\mathsfbfsl{\Sigma}",
    "\uD7A3": rb"\mathsfbfsl{\Tau}",
    "\uD7A4": rb"\mathsfbfsl{\Upsilon}",
    "\uD7A5": rb"\mathsfbfsl{\Phi}",
    "\uD7A6": rb"\mathsfbfsl{\Chi}",
    "\uD7A7": rb"\mathsfbfsl{\Psi}",
    "\uD7A8": rb"\mathsfbfsl{\Omega}",
    "\uD7A9": rb"\mathsfbfsl{\nabla}",
    "\uD7AA": rb"\mathsfbfsl{\Alpha}",
    "\uD7AB": rb"\mathsfbfsl{\Beta}",
    "\uD7AC": rb"\mathsfbfsl{\Gamma}",
    "\uD7AD": rb"\mathsfbfsl{\Delta}",
    "\uD7AE": rb"\mathsfbfsl{\Epsilon}",
    "\uD7AF": rb"\mathsfbfsl{\Zeta}",
    "\uD7B0": rb"\mathsfbfsl{\Eta}",
    "\uD7B1": rb"\mathsfbfsl{\vartheta}",
    "\uD7B2": rb"\mathsfbfsl{\Iota}",
    "\uD7B3": rb"\mathsfbfsl{\Kappa}",
    "\uD7B4": rb"\mathsfbfsl{\Lambda}",
    "\uD7B7": rb"\mathsfbfsl{\Xi}",
    "\uD7B9": rb"\mathsfbfsl{\Pi}",
    "\uD7BA": rb"\mathsfbfsl{\Rho}",
    "\uD7BB": rb"\mathsfbfsl{\varsigma}",
    "\uD7BC": rb"\mathsfbfsl{\Sigma}",
    "\uD7BD": rb"\mathsfbfsl{\Tau}",
    "\uD7BE": rb"\mathsfbfsl{\Upsilon}",
    "\uD7BF": rb"\mathsfbfsl{\Phi}",
    "\uD7C0": rb"\mathsfbfsl{\Chi}",
    "\uD7C1": rb"\mathsfbfsl{\Psi}",
    "\uD7C2": rb"\mathsfbfsl{\Omega}",
    "\uD7C3": rb"\partial{}",
    "\uD7C4": rb"\in",
    "\uD7C5": rb"\mathsfbfsl{\vartheta}",
    "\uD7C6": rb"\mathsfbfsl{\varkappa}",
    "\uD7C7": rb"\mathsfbfsl{\phi}",
    "\uD7C8": rb"\mathsfbfsl{\varrho}",
    "\uD7C9": rb"\mathsfbfsl{\varpi}",
    "\uD7CE": rb"\mathbf{0}",
    "\uD7CF": rb"\mathbf{1}",
    "\uD7D0": rb"\mathbf{2}",
    "\uD7D1": rb"\mathbf{3}",
    "\uD7D2": rb"\mathbf{4}",
    "\uD7D3": rb"\mathbf{5}",
    "\uD7D4": rb"\mathbf{6}",
    "\uD7D5": rb"\mathbf{7}",
    "\uD7D6": rb"\mathbf{8}",
    "\uD7D7": rb"\mathbf{9}",
    "\uD7D8": rb"\mathbb{0}",
    "\uD7D9": rb"\mathbb{1}",
    "\uD7DA": rb"\mathbb{2}",
    "\uD7DB": rb"\mathbb{3}",
    "\uD7DC": rb"\mathbb{4}",
    "\uD7DD": rb"\mathbb{5}",
    "\uD7DE": rb"\mathbb{6}",
    "\uD7DF": rb"\mathbb{7}",
    "\uD7E0": rb"\mathbb{8}",
    "\uD7E1": rb"\mathbb{9}",
    "\uD7E2": rb"\mathsf{0}",
    "\uD7E3": rb"\mathsf{1}",
    "\uD7E4": rb"\mathsf{2}",
    "\uD7E5": rb"\mathsf{3}",
    "\uD7E6": rb"\mathsf{4}",
    "\uD7E7": rb"\mathsf{5}",
    "\uD7E8": rb"\mathsf{6}",
    "\uD7E9": rb"\mathsf{7}",
    "\uD7EA": rb"\mathsf{8}",
    "\uD7EB": rb"\mathsf{9}",
    "\uD7EC": rb"\mathsfbf{0}",
    "\uD7ED": rb"\mathsfbf{1}",
    "\uD7EE": rb"\mathsfbf{2}",
    "\uD7EF": rb"\mathsfbf{3}",
    "\uD7F0": rb"\mathsfbf{4}",
    "\uD7F1": rb"\mathsfbf{5}",
    "\uD7F2": rb"\mathsfbf{6}",
    "\uD7F3": rb"\mathsfbf{7}",
    "\uD7F4": rb"\mathsfbf{8}",
    "\uD7F5": rb"\mathsfbf{9}",
    "\uD7F6": rb"\mathtt{0}",
    "\uD7F7": rb"\mathtt{1}",
    "\uD7F8": rb"\mathtt{2}",
    "\uD7F9": rb"\mathtt{3}",
    "\uD7FA": rb"\mathtt{4}",
    "\uD7FB": rb"\mathtt{5}",
    "\uD7FC": rb"\mathtt{6}",
    "\uD7FD": rb"\mathtt{7}",
    "\uD7FE": rb"\mathtt{8}",
    "\uD7FF": rb"\mathtt{9}",
}

# Some multi-character items in the source dataset that we can't
# translate. This is probably not exhaustive.
#    u"\u2009\u200A\u200A": r"\;",
#    u"\u2242\u0338": r"\NotEqualTilde{}",
#    u"\u224B\u0338": r"\not\apid{}",
#    u"\u224E\u0338": r"\NotHumpDownHump{}",
#    u"\u224F\u0338": r"\NotHumpEqual{}",
#    u"\u2250\u0338": r"\not\doteq",
#    u"\u2268\uFE00": r"\lvertneqq{}",
#    u"\u2269\uFE00": r"\gvertneqq{}",
#    u"\u226A\u0338": r"\NotLessLess{}",
#    u"\u226B\u0338": r"\NotGreaterGreater{}",
#    u"\u227E\u0338": r"\NotPrecedesTilde{}",
#    u"\u227F\u0338": r"\NotSucceedsTilde{}",
#    u"\u228A\uFE00": r"\varsubsetneqq{}",
#    u"\u228B\uFE00": r"\varsupsetneq{}",
#    u"\u228F\u0338": r"\NotSquareSubset{}",
#    u"\u2290\u0338": r"\NotSquareSuperset{}",
#    u"\u2933\u0338": r"\ElsevierGlyph{E21D}",
#    u"\u29CF\u0338": r"\NotLeftTriangleBar{}",
#    u"\u29D0\u0338": r"\NotRightTriangleBar{}",
#    u"\u2A7D\u0338": r"\nleqslant{}",
#    u"\u2A7E\u0338": r"\ngeqslant{}",
#    u"\u2AA1\u0338": r"\NotNestedLessLess{}",
#    u"\u2AA2\u0338": r"\NotNestedGreaterGreater{}",
#    u"\u2AAF\u0338": r"\not\preceq{}",
#    u"\u2AB0\u0338": r"\not\succeq{}",
#    u"\u2AC5\u0338": r"\nsubseteqq{}",
#    u"\u2AC6\u0338": r"\nsupseteqq",
#    u"\u2AFD\u20E5": r"{\rlap{\textbackslash}{{/}\!\!{/}}}",

unicode_to_latex_table = dict(
    (ord(k), v.decode("ascii")) for k, v in unicode_to_latex_table_base.items()
)
unicode_to_latex_string = lambda u: u.translate(unicode_to_latex_table)
unicode_to_latex_bytes = lambda u: u.translate(unicode_to_latex_table).encode("ascii")
unicode_to_latex = unicode_to_latex_string
